@@ -13,7 +13,6 @@ import pytest
 
 pytestmark = pytest.mark.extra_artifacts(
     [
-        ".hypothesis/examples/*",
         "K*",
         "canonical*",
         "delv.out*",
@@ -22,11 +21,10 @@ pytestmark = pytest.mark.extra_artifacts(
         "dsfromkey.out.*",
         "keygen*.err*",
         "named.secroots.*",
-        "nosign.before",
         "nsupdate.out.*",
         "python.out.*",
         "rndc.out.*",
-        "signing.out*",
+        "signing.out.*",
         "*/K*",
         "*/dsset-*",
         "*/managed.conf",
@@ -44,34 +42,23 @@ pytestmark = pytest.mark.extra_artifacts(
         "ns2/algroll.db",
         "ns2/badparam.db",
         "ns2/badparam.db.bad",
-        "ns2/cdnskey-kskonly.secure.db",
-        "ns2/cdnskey-kskonly.secure.id",
         "ns2/cdnskey-update.secure.db",
         "ns2/cdnskey-update.secure.id",
         "ns2/cdnskey-x.secure.db",
         "ns2/cdnskey.secure.db",
-        "ns2/cds-kskonly.secure.db",
-        "ns2/cds-kskonly.secure.id",
         "ns2/cds-update.secure.db",
         "ns2/cds-update.secure.id",
         "ns2/cds-x.secure.db",
-        "ns2/cds-x.secure.db",
         "ns2/cds.secure.db",
-        "ns2/dnskey-rrsigs-stripped.db",
-        "ns2/dnskey-rrsigs-stripped.db.next",
-        "ns2/dnskey-rrsigs-stripped.db.stripped",
-        "ns2/child.ds-rrsigs-stripped.db",
-        "ns2/ds-rrsigs-stripped.db",
-        "ns2/ds-rrsigs-stripped.db.next",
-        "ns2/ds-rrsigs-stripped.db.stripped",
         "ns2/example.db",
         "ns2/in-addr.arpa.db",
         "ns2/lazy-ksk.db",
         "ns2/managed.db",
         "ns2/nsec3chain-test.db",
+        "ns2/settime.out.updatecheck-kskonly.secure.ksk",
+        "ns2/settime.out.updatecheck-kskonly.secure.zsk",
         "ns2/single-nsec3.db",
         "ns2/too-many-iterations.db",
-        "ns2/inconsistent.db",
         "ns2/trusted.db",
         "ns2/updatecheck-kskonly.secure.ksk.id",
         "ns2/updatecheck-kskonly.secure.ksk.key",
@@ -101,14 +88,12 @@ pytestmark = pytest.mark.extra_artifacts(
         "ns3/example.bk",
         "ns3/expired.example.db",
         "ns3/expiring.example.db",
-        "ns3/extrabadkey.example.db",
         "ns3/future.example.db",
         "ns3/keyless.example.db",
         "ns3/kskonly.example.db",
         "ns3/lower.example.db",
         "ns3/managed-future.example.db",
         "ns3/multiple.example.db",
-        "ns3/nosign.example.db",
         "ns3/nsec3-unknown.example.db",
         "ns3/nsec3.example.db",
         "ns3/nsec3.nsec3.example.db",
@@ -119,7 +104,6 @@ pytestmark = pytest.mark.extra_artifacts(
         "ns3/optout.example.db",
         "ns3/optout.nsec3.example.db",
         "ns3/optout.optout.example.db",
-        "ns3/publish-inactive.example.db",
         "ns3/revkey.example.db",
         "ns3/revoked.managed.db",
         "ns3/revoked.trusted.db",
@@ -156,7 +140,6 @@ pytestmark = pytest.mark.extra_artifacts(
         "ns6/optout-tld.db",
         "ns7/split-rrsig.db",
         "ns7/split-rrsig.db.unsplit",
-        "ns8/managed-keys.bind",
         "signer/example.db",
         "signer/example.db.after",
         "signer/example.db.before",
