@@ -13,27 +13,18 @@
 
 import os
 from pathlib import Path
-import platform
-import shutil
-import ssl
 import subprocess
 
 import pytest
 
-long_test = pytest.mark.skipif(
-    not os.environ.get("CI_ENABLE_LONG_TESTS"), reason="CI_ENABLE_LONG_TESTS not set"
-)
 
-live_internet_test = pytest.mark.skipif(
-    not os.environ.get("CI_ENABLE_LIVE_INTERNET_TESTS"),
-    reason="CI_ENABLE_LIVE_INTERNET_TESTS not set",
+long_test = pytest.mark.skipif(
+    not os.environ.get("CI_ENABLE_ALL_TESTS"), reason="CI_ENABLE_ALL_TESTS not set"
 )
 
 
 def feature_test(feature):
-    feature_test_bin = os.environ.get("FEATURETEST")
-    if not feature_test_bin:  # this can be the case when running doctest
-        return False
+    feature_test_bin = os.environ["FEATURETEST"]
     try:
         subprocess.run([feature_test_bin, feature], check=True)
     except subprocess.CalledProcessError as exc:
@@ -56,8 +47,12 @@ def is_dnsrps_available():
     return True
 
 
-def is_host_freebsd_13(*_):
-    return platform.system() == "FreeBSD" and platform.release().startswith("13")
+def with_dnstap(*args):  # pylint: disable=unused-argument
+    return feature_test("--enable-dnstap")
+
+
+def with_tsan(*args):  # pylint: disable=unused-argument
+    return feature_test("--tsan")
 
 
 have_libxml2 = pytest.mark.skipif(
@@ -72,19 +67,20 @@ dnsrps_enabled = pytest.mark.skipif(
     not is_dnsrps_available(), reason="dnsrps disabled in the build"
 )
 
-supported_openssl_version = pytest.mark.skipif(
-    ssl.OPENSSL_VERSION_NUMBER >= 0x300000C0
-    and ssl.OPENSSL_VERSION_NUMBER < 0x300000E0,
-    reason="unsupported OpenSSL [GL #4814]",
-)
 
+try:
+    import flaky as flaky_pkg  # type: ignore
+except ModuleNotFoundError:
+    # In case the flaky package is not installed, run the tests as usual
+    # without any attempts to re-run them.
+    # pylint: disable=unused-argument
+    def flaky(*args, **kwargs):
+        """Mock decorator that doesn't do anything special, just returns the function."""
 
-softhsm2_environment = pytest.mark.skipif(
-    not (
-        os.getenv("SOFTHSM2_CONF")
-        and os.getenv("SOFTHSM2_MODULE")
-        and shutil.which("pkcs11-tool")
-        and shutil.which("softhsm2-util")
-    ),
-    reason="SOFTHSM2_CONF and SOFTHSM2_MODULE environmental variables must be set and pkcs11-tool and softhsm2-util tools present",
-)
+        def wrapper(wrapped_obj):
+            return wrapped_obj
+
+        return wrapper
+
+else:
+    flaky = flaky_pkg.flaky
