@@ -335,7 +335,7 @@ static isc_result_t
 dbfind_name(dns_adbname_t *, isc_stdtime_t, dns_rdatatype_t);
 static isc_result_t
 fetch_name(dns_adbname_t *, bool, unsigned int, isc_counter_t *qc,
-	   dns_rdatatype_t);
+	   isc_counter_t *gqc, dns_rdatatype_t);
 static void
 destroy(dns_adb_t *);
 static void
@@ -531,7 +531,7 @@ ttlclamp(dns_ttl_t ttl) {
 		ttl = ADB_CACHE_MAXIMUM;
 	}
 
-	return (ttl);
+	return ttl;
 }
 
 /*
@@ -640,12 +640,12 @@ import_rdataset(dns_adbname_t *adbname, dns_rdataset_t *rdataset,
 		UNREACHABLE();
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static bool
 match_ptr(void *node, const void *key) {
-	return (node == key);
+	return node == key;
 }
 
 /*
@@ -832,12 +832,12 @@ set_target(dns_adb_t *adb, const dns_name_t *name, const dns_name_t *fname,
 		 */
 		result = dns_rdataset_first(rdataset);
 		if (result != ISC_R_SUCCESS) {
-			return (result);
+			return result;
 		}
 		dns_rdataset_current(rdataset, &rdata);
 		result = dns_rdata_tostruct(&rdata, &cname, NULL);
 		if (result != ISC_R_SUCCESS) {
-			return (result);
+			return result;
 		}
 		dns_name_dup(&cname.cname, adb->mctx, target);
 		dns_rdata_freestruct(&cname);
@@ -858,12 +858,12 @@ set_target(dns_adb_t *adb, const dns_name_t *name, const dns_name_t *fname,
 		 */
 		result = dns_rdataset_first(rdataset);
 		if (result != ISC_R_SUCCESS) {
-			return (result);
+			return result;
 		}
 		dns_rdataset_current(rdataset, &rdata);
 		result = dns_rdata_tostruct(&rdata, &dname, NULL);
 		if (result != ISC_R_SUCCESS) {
-			return (result);
+			return result;
 		}
 
 		/*
@@ -876,12 +876,12 @@ set_target(dns_adb_t *adb, const dns_name_t *name, const dns_name_t *fname,
 					      NULL);
 		dns_rdata_freestruct(&dname);
 		if (result != ISC_R_SUCCESS) {
-			return (result);
+			return result;
 		}
 		dns_name_dup(new_target, adb->mctx, target);
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 /*
@@ -988,7 +988,7 @@ new_adbname(dns_adb_t *adb, const dns_name_t *dnsname, unsigned int flags) {
 	dns_name_init(&name->target, NULL);
 
 	inc_adbstats(adb, dns_adbstats_namescnt);
-	return (name);
+	return name;
 }
 
 #if DNS_ADB_TRACE
@@ -1028,7 +1028,7 @@ new_adbnamehook(dns_adb_t *adb) {
 		.magic = DNS_ADBNAMEHOOK_MAGIC,
 	};
 
-	return (nh);
+	return nh;
 }
 
 static void
@@ -1073,7 +1073,7 @@ new_adbentry(dns_adb_t *adb, const isc_sockaddr_t *addr, isc_stdtime_t now) {
 
 	inc_adbstats(adb, dns_adbstats_entriescnt);
 
-	return (entry);
+	return entry;
 }
 
 static void
@@ -1129,7 +1129,7 @@ new_adbfind(dns_adb_t *adb, in_port_t port) {
 
 	find->magic = DNS_ADBFIND_MAGIC;
 
-	return (find);
+	return find;
 }
 
 static void
@@ -1167,7 +1167,7 @@ new_adbfetch(dns_adb_t *adb) {
 
 	fetch->magic = DNS_ADBFETCH_MAGIC;
 
-	return (fetch);
+	return fetch;
 }
 
 static void
@@ -1208,7 +1208,7 @@ new_adbaddrinfo(dns_adb_t *adb, dns_adbentry_t *entry, in_port_t port) {
 
 	isc_sockaddr_setport(&ai->sockaddr, port);
 
-	return (ai);
+	return ai;
 }
 
 static void
@@ -1240,10 +1240,10 @@ match_adbname(void *node, const void *key) {
 	if ((adbname0->flags & ADBNAME_FLAGS_MASK) !=
 	    (adbname1->flags & ADBNAME_FLAGS_MASK))
 	{
-		return (false);
+		return false;
 	}
 
-	return (dns_name_equal(adbname0->name, adbname1->name));
+	return dns_name_equal(adbname0->name, adbname1->name);
 }
 
 static uint32_t
@@ -1255,7 +1255,7 @@ hash_adbname(const dns_adbname_t *adbname) {
 	isc_hash32_hash(&hash, adbname->name->ndata, adbname->name->length,
 			false);
 	isc_hash32_hash(&hash, &flags, sizeof(flags), true);
-	return (isc_hash32_finalize(&hash));
+	return isc_hash32_finalize(&hash);
 }
 
 /*
@@ -1336,7 +1336,7 @@ get_attached_and_locked_name(dns_adb_t *adb, const dns_name_t *name,
 	 */
 	RWUNLOCK(&adb->names_lock, locktype);
 
-	return (adbname);
+	return adbname;
 }
 
 static void
@@ -1353,7 +1353,7 @@ static bool
 match_adbentry(void *node, const void *key) {
 	dns_adbentry_t *adbentry = node;
 
-	return (isc_sockaddr_equal(&adbentry->sockaddr, key));
+	return isc_sockaddr_equal(&adbentry->sockaddr, key);
 }
 
 /*
@@ -1446,7 +1446,7 @@ get_attached_and_locked_entry(dns_adb_t *adb, isc_stdtime_t now,
 
 	RWUNLOCK(&adb->entries_lock, locktype);
 
-	return (adbentry);
+	return adbentry;
 }
 
 static void
@@ -1533,12 +1533,12 @@ maybe_expire_name(dns_adbname_t *adbname, isc_stdtime_t now) {
 
 	/* Leave this name alone if it still has active namehooks... */
 	if (NAME_HAS_V4(adbname) || NAME_HAS_V6(adbname)) {
-		return (false);
+		return false;
 	}
 
 	/* ...an active fetch in progres... */
 	if (NAME_FETCH(adbname)) {
-		return (false);
+		return false;
 	}
 
 	/* ... or is not yet expired. */
@@ -1546,12 +1546,12 @@ maybe_expire_name(dns_adbname_t *adbname, isc_stdtime_t now) {
 	    !EXPIRE_OK(adbname->expire_v6, now) ||
 	    !EXPIRE_OK(adbname->expire_target, now))
 	{
-		return (false);
+		return false;
 	}
 
 	expire_name(adbname, DNS_ADB_EXPIRED);
 
-	return (true);
+	return true;
 }
 
 static void
@@ -1576,14 +1576,14 @@ expire_entry(dns_adbentry_t *adbentry) {
 static bool
 entry_expired(dns_adbentry_t *adbentry, isc_stdtime_t now) {
 	if (!ISC_LIST_EMPTY(adbentry->nhs)) {
-		return (false);
+		return false;
 	}
 
 	if (!EXPIRE_OK(adbentry->expires, now)) {
-		return (false);
+		return false;
 	}
 
-	return (true);
+	return true;
 }
 
 static bool
@@ -1592,10 +1592,10 @@ maybe_expire_entry(dns_adbentry_t *adbentry, isc_stdtime_t now) {
 
 	if (entry_expired(adbentry, now)) {
 		expire_entry(adbentry);
-		return (true);
+		return true;
 	}
 
-	return (false);
+	return false;
 }
 
 /*%
@@ -1926,7 +1926,7 @@ dns_adb_createfind(dns_adb_t *adb, isc_loop_t *loop, isc_job_cb cb, void *cbarg,
 		   const dns_name_t *name, const dns_name_t *qname,
 		   dns_rdatatype_t qtype ISC_ATTR_UNUSED, unsigned int options,
 		   isc_stdtime_t now, dns_name_t *target, in_port_t port,
-		   unsigned int depth, isc_counter_t *qc,
+		   unsigned int depth, isc_counter_t *qc, isc_counter_t *gqc,
 		   dns_adbfind_t **findp) {
 	isc_result_t result = ISC_R_UNEXPECTED;
 	dns_adbfind_t *find = NULL;
@@ -1955,7 +1955,7 @@ dns_adb_createfind(dns_adb_t *adb, isc_loop_t *loop, isc_job_cb cb, void *cbarg,
 		DP(DEF_LEVEL, "dns_adb_createfind: returning "
 			      "ISC_R_SHUTTINGDOWN");
 
-		return (ISC_R_SHUTTINGDOWN);
+		return ISC_R_SHUTTINGDOWN;
 	}
 
 	if (now == 0) {
@@ -2136,7 +2136,7 @@ fetch:
 		 * Start V4.
 		 */
 		if (WANT_INET(wanted_fetches) &&
-		    fetch_name(adbname, start_at_zone, depth, qc,
+		    fetch_name(adbname, start_at_zone, depth, qc, gqc,
 			       dns_rdatatype_a) == ISC_R_SUCCESS)
 		{
 			DP(DEF_LEVEL,
@@ -2149,7 +2149,7 @@ fetch:
 		 * Start V6.
 		 */
 		if (WANT_INET6(wanted_fetches) &&
-		    fetch_name(adbname, start_at_zone, depth, qc,
+		    fetch_name(adbname, start_at_zone, depth, qc, gqc,
 			       dns_rdatatype_aaaa) == ISC_R_SUCCESS)
 		{
 			DP(DEF_LEVEL,
@@ -2242,7 +2242,7 @@ post_copy:
 	UNLOCK(&adbname->lock);
 	dns_adbname_detach(&adbname);
 
-	return (result);
+	return result;
 }
 
 void
@@ -2317,17 +2317,29 @@ dns_adb_cancelfind(dns_adbfind_t *find) {
 		 * locks in that order, to match locking hierarchy
 		 * elsewhere.
 		 */
+		dns_adbname_ref(adbname);
 		UNLOCK(&find->lock);
+
+		/*
+		 * Other thread could cancel the find between the unlock and
+		 * lock, so we need to recheck whether the adbname is still
+		 * valid and reference the adbname, so it does not vanish before
+		 * we have a chance to lock it again.
+		 */
+
 		LOCK(&adbname->lock);
 		LOCK(&find->lock);
 
-		ISC_LIST_UNLINK(adbname->finds, find, plink);
-		find->adbname = NULL;
+		if (find->adbname != NULL) {
+			ISC_LIST_UNLINK(find->adbname->finds, find, plink);
+			find->adbname = NULL;
+		}
 
 		find_sendevent(find);
 
 		UNLOCK(&find->lock);
 		UNLOCK(&adbname->lock);
+		dns_adbname_detach(&adbname);
 	}
 }
 
@@ -2335,7 +2347,7 @@ unsigned int
 dns_adb_findstatus(dns_adbfind_t *find) {
 	REQUIRE(DNS_ADBFIND_VALID(find));
 
-	return (atomic_load(&find->status));
+	return atomic_load(&find->status);
 }
 
 void
@@ -2578,11 +2590,11 @@ putstr(isc_buffer_t **b, const char *str) {
 
 	result = isc_buffer_reserve(*b, strlen(str));
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 
 	isc_buffer_putstr(*b, str);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
@@ -2623,7 +2635,7 @@ dns_adb_dumpquota(dns_adb_t *adb, isc_buffer_t **buf) {
 	isc_hashmap_iter_destroy(&it);
 	RWUNLOCK(&adb->entries_lock, isc_rwlocktype_read);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -2770,7 +2782,7 @@ dbfind_name(dns_adbname_t *adbname, isc_stdtime_t now, dns_rdatatype_t rdtype) {
 		dns_rdataset_disassociate(&rdataset);
 	}
 
-	return (result);
+	return result;
 }
 
 static void
@@ -2932,7 +2944,7 @@ check_result:
 out:
 	dns_resolver_destroyfetch(&fetch->fetch);
 	free_adbfetch(adb, &fetch);
-	isc_mem_putanddetach(&resp->mctx, resp, sizeof(*resp));
+	dns_resolver_freefresp(&resp);
 	if (astat != DNS_ADB_CANCELED) {
 		clean_finds_at_name(name, astat, address_type);
 	}
@@ -2943,7 +2955,7 @@ out:
 
 static isc_result_t
 fetch_name(dns_adbname_t *adbname, bool start_at_zone, unsigned int depth,
-	   isc_counter_t *qc, dns_rdatatype_t type) {
+	   isc_counter_t *qc, isc_counter_t *gqc, dns_rdatatype_t type) {
 	isc_result_t result;
 	dns_adbfetch_t *fetch = NULL;
 	dns_adb_t *adb = NULL;
@@ -2999,7 +3011,7 @@ fetch_name(dns_adbname_t *adbname, bool start_at_zone, unsigned int depth,
 	 */
 	result = dns_resolver_createfetch(
 		adb->res, adbname->name, type, name, nameservers, NULL, NULL, 0,
-		options, depth, qc, isc_loop(), fetch_callback, adbname,
+		options, depth, qc, gqc, isc_loop(), fetch_callback, adbname,
 		&fetch->rdataset, NULL, &fetch->fetch);
 	if (result != ISC_R_SUCCESS) {
 		DP(ENTER_LEVEL, "fetch_name: createfetch failed with %s",
@@ -3026,7 +3038,7 @@ cleanup:
 		dns_rdataset_disassociate(&rdataset);
 	}
 
-	return (result);
+	return result;
 }
 
 void
@@ -3274,7 +3286,7 @@ dns_adb_getudpsize(dns_adb_t *adb, dns_adbaddrinfo_t *addr) {
 	size = entry->udpsize;
 	UNLOCK(&entry->lock);
 
-	return (size);
+	return size;
 }
 
 void
@@ -3329,7 +3341,7 @@ dns_adb_getcookie(dns_adbaddrinfo_t *addr, unsigned char *cookie, size_t len) {
 unlock:
 	UNLOCK(&entry->lock);
 
-	return (len);
+	return len;
 }
 
 isc_result_t
@@ -3345,7 +3357,7 @@ dns_adb_findaddrinfo(dns_adb_t *adb, const isc_sockaddr_t *sa,
 	in_port_t port;
 
 	if (atomic_load(&adb->exiting)) {
-		return (ISC_R_SHUTTINGDOWN);
+		return ISC_R_SHUTTINGDOWN;
 	}
 
 	entry = get_attached_and_locked_entry(adb, now, sa);
@@ -3358,7 +3370,7 @@ dns_adb_findaddrinfo(dns_adb_t *adb, const isc_sockaddr_t *sa,
 
 	dns_adbentry_detach(&entry);
 
-	return (result);
+	return result;
 }
 
 void
@@ -3524,14 +3536,14 @@ adbentry_overquota(dns_adbentry_t *entry) {
 	uint_fast32_t quota = atomic_load_relaxed(&entry->quota);
 	uint_fast32_t active = atomic_load_acquire(&entry->active);
 
-	return (quota != 0 && active >= quota);
+	return quota != 0 && active >= quota;
 }
 
 bool
 dns_adb_overquota(dns_adb_t *adb ISC_ATTR_UNUSED, dns_adbaddrinfo_t *addrinfo) {
 	REQUIRE(DNS_ADBADDRINFO_VALID(addrinfo));
 
-	return (adbentry_overquota(addrinfo->entry));
+	return adbentry_overquota(addrinfo->entry);
 }
 
 void
@@ -3560,5 +3572,5 @@ isc_stats_t *
 dns_adb_getstats(dns_adb_t *adb) {
 	REQUIRE(DNS_ADB_VALID(adb));
 
-	return (adb->stats);
+	return adb->stats;
 }
