@@ -69,7 +69,7 @@ static isc_result_t
 digest_callback(void *arg, isc_region_t *data) {
 	dst_context_t *ctx = arg;
 
-	return (dst_context_adddata(ctx, data));
+	return dst_context_adddata(ctx, data);
 }
 
 static void
@@ -84,8 +84,8 @@ inc_stat(isc_statscounter_t counter) {
  */
 static int
 rdata_compare_wrapper(const void *rdata1, const void *rdata2) {
-	return (dns_rdata_compare((const dns_rdata_t *)rdata1,
-				  (const dns_rdata_t *)rdata2));
+	return dns_rdata_compare((const dns_rdata_t *)rdata1,
+				 (const dns_rdata_t *)rdata2);
 }
 
 /*
@@ -109,7 +109,7 @@ rdataset_to_sortedarray(dns_rdataset_t *set, isc_mem_t *mctx,
 	if (ret != ISC_R_SUCCESS) {
 		dns_rdataset_disassociate(&rdataset);
 		isc_mem_cput(mctx, data, n, sizeof(dns_rdata_t));
-		return (ret);
+		return ret;
 	}
 
 	/*
@@ -127,7 +127,7 @@ rdataset_to_sortedarray(dns_rdataset_t *set, isc_mem_t *mctx,
 	*rdata = data;
 	*nrdata = n;
 	dns_rdataset_disassociate(&rdataset);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
@@ -147,7 +147,7 @@ dns_dnssec_keyfromrdata(const dns_name_t *name, const dns_rdata_t *rdata,
 	dns_rdata_toregion(rdata, &r);
 	isc_buffer_init(&b, r.base, r.length);
 	isc_buffer_add(&b, r.length);
-	return (dst_key_fromdns(name, rdata->rdclass, &b, mctx, key));
+	return dst_key_fromdns(name, rdata->rdclass, &b, mctx, key);
 }
 
 static isc_result_t
@@ -163,7 +163,7 @@ digest_sig(dst_context_t *ctx, bool downcase, dns_rdata_t *sigrdata,
 	r.length = 18;
 	ret = dst_context_adddata(ctx, &r);
 	if (ret != ISC_R_SUCCESS) {
-		return (ret);
+		return ret;
 	}
 	if (downcase) {
 		dns_fixedname_init(&fname);
@@ -176,7 +176,7 @@ digest_sig(dst_context_t *ctx, bool downcase, dns_rdata_t *sigrdata,
 		dns_name_toregion(&rrsig->signer, &r);
 	}
 
-	return (dst_context_adddata(ctx, &r));
+	return dst_context_adddata(ctx, &r);
 }
 
 isc_result_t
@@ -208,7 +208,7 @@ dns_dnssec_sign(const dns_name_t *name, dns_rdataset_t *set, dst_key_t *key,
 	REQUIRE(sigrdata != NULL);
 
 	if (*inception >= *expire) {
-		return (DNS_R_INVALIDTIME);
+		return DNS_R_INVALIDTIME;
 	}
 
 	/*
@@ -216,10 +216,10 @@ dns_dnssec_sign(const dns_name_t *name, dns_rdataset_t *set, dst_key_t *key,
 	 */
 	flags = dst_key_flags(key);
 	if ((flags & DNS_KEYTYPE_NOAUTH) != 0) {
-		return (DNS_R_KEYUNAUTHORIZED);
+		return DNS_R_KEYUNAUTHORIZED;
 	}
 	if ((flags & DNS_KEYFLAG_OWNERMASK) != DNS_KEYOWNER_ZONE) {
-		return (DNS_R_KEYUNAUTHORIZED);
+		return DNS_R_KEYUNAUTHORIZED;
 	}
 
 	sig.mctx = mctx;
@@ -249,7 +249,7 @@ dns_dnssec_sign(const dns_name_t *name, dns_rdataset_t *set, dst_key_t *key,
 	sig.keyid = dst_key_id(key);
 	ret = dst_key_sigsize(key, &sigsize);
 	if (ret != ISC_R_SUCCESS) {
-		return (ret);
+		return ret;
 	}
 	sig.siglen = sigsize;
 	/*
@@ -327,7 +327,6 @@ dns_dnssec_sign(const dns_name_t *name, dns_rdataset_t *set, dst_key_t *key,
 		 * Digest the length of the rdata.
 		 */
 		isc_buffer_init(&lenbuf, &len, sizeof(len));
-		INSIST(rdatas[i].length < 65536);
 		isc_buffer_putuint16(&lenbuf, (uint16_t)rdatas[i].length);
 		isc_buffer_usedregion(&lenbuf, &lenr);
 		ret = dst_context_adddata(ctx, &lenr);
@@ -366,7 +365,7 @@ cleanup_databuf:
 	isc_buffer_free(&databuf);
 	isc_mem_put(mctx, sig.signature, sig.siglen);
 
-	return (ret);
+	return ret;
 }
 
 isc_result_t
@@ -395,16 +394,16 @@ dns_dnssec_verify(const dns_name_t *name, dns_rdataset_t *set, dst_key_t *key,
 
 	ret = dns_rdata_tostruct(sigrdata, &sig, NULL);
 	if (ret != ISC_R_SUCCESS) {
-		return (ret);
+		return ret;
 	}
 
 	if (set->type != sig.covered) {
-		return (DNS_R_SIGINVALID);
+		return DNS_R_SIGINVALID;
 	}
 
 	if (isc_serial_lt(sig.timeexpire, sig.timesigned)) {
 		inc_stat(dns_dnssecstats_fail);
-		return (DNS_R_SIGINVALID);
+		return DNS_R_SIGINVALID;
 	}
 
 	if (!ignoretime) {
@@ -415,10 +414,10 @@ dns_dnssec_verify(const dns_name_t *name, dns_rdataset_t *set, dst_key_t *key,
 		 */
 		if (isc_serial_lt((uint32_t)now, sig.timesigned)) {
 			inc_stat(dns_dnssecstats_fail);
-			return (DNS_R_SIGFUTURE);
+			return DNS_R_SIGFUTURE;
 		} else if (isc_serial_lt(sig.timeexpire, (uint32_t)now)) {
 			inc_stat(dns_dnssecstats_fail);
-			return (DNS_R_SIGEXPIRED);
+			return DNS_R_SIGEXPIRED;
 		}
 	}
 
@@ -432,19 +431,19 @@ dns_dnssec_verify(const dns_name_t *name, dns_rdataset_t *set, dst_key_t *key,
 	case dns_rdatatype_dnskey:
 		if (!dns_name_equal(name, &sig.signer)) {
 			inc_stat(dns_dnssecstats_fail);
-			return (DNS_R_SIGINVALID);
+			return DNS_R_SIGINVALID;
 		}
 		break;
 	case dns_rdatatype_ds:
 		if (dns_name_equal(name, &sig.signer)) {
 			inc_stat(dns_dnssecstats_fail);
-			return (DNS_R_SIGINVALID);
+			return DNS_R_SIGINVALID;
 		}
 		FALLTHROUGH;
 	default:
 		if (!dns_name_issubdomain(name, &sig.signer)) {
 			inc_stat(dns_dnssecstats_fail);
-			return (DNS_R_SIGINVALID);
+			return DNS_R_SIGINVALID;
 		}
 		break;
 	}
@@ -455,11 +454,11 @@ dns_dnssec_verify(const dns_name_t *name, dns_rdataset_t *set, dst_key_t *key,
 	flags = dst_key_flags(key);
 	if ((flags & DNS_KEYTYPE_NOAUTH) != 0) {
 		inc_stat(dns_dnssecstats_fail);
-		return (DNS_R_KEYUNAUTHORIZED);
+		return DNS_R_KEYUNAUTHORIZED;
 	}
 	if ((flags & DNS_KEYFLAG_OWNERMASK) != DNS_KEYOWNER_ZONE) {
 		inc_stat(dns_dnssecstats_fail);
-		return (DNS_R_KEYUNAUTHORIZED);
+		return DNS_R_KEYUNAUTHORIZED;
 	}
 
 again:
@@ -539,7 +538,6 @@ again:
 		 * Digest the rdata length.
 		 */
 		isc_buffer_init(&lenbuf, &len, sizeof(len));
-		INSIST(rdatas[i].length < 65536);
 		isc_buffer_putuint16(&lenbuf, (uint16_t)rdatas[i].length);
 		isc_buffer_usedregion(&lenbuf, &lenr);
 
@@ -601,7 +599,7 @@ cleanup_struct:
 		inc_stat(dns_dnssecstats_wildcard);
 		ret = DNS_R_FROMWILDCARD;
 	}
-	return (ret);
+	return ret;
 }
 
 bool
@@ -632,7 +630,7 @@ dns_dnssec_keyactive(dst_key_t *key, isc_stdtime_t now) {
 	 * keys are assumed active.
 	 */
 	if (major == 1 && minor <= 2) {
-		return (true);
+		return true;
 	}
 
 	hint_publish = dst_key_is_published(key, now, &publish);
@@ -642,18 +640,18 @@ dns_dnssec_keyactive(dst_key_t *key, isc_stdtime_t now) {
 	hint_remove = dst_key_is_removed(key, now, &remove);
 
 	if (hint_remove) {
-		return (false);
+		return false;
 	}
 	if (hint_publish && hint_revoke) {
-		return (true);
+		return true;
 	}
 	if (hint_zsign && zsk) {
-		return (true);
+		return true;
 	}
 	if (hint_ksign && ksk) {
-		return (true);
+		return true;
 	}
-	return (false);
+	return false;
 }
 
 /*%<
@@ -685,14 +683,14 @@ syncpublish(dst_key_t *key, isc_stdtime_t now) {
 	 * Smart signing started with key format 1.3
 	 */
 	if (major == 1 && minor <= 2) {
-		return (false);
+		return false;
 	}
 
 	/* Check kasp state first. */
 	result = dst_key_getstate(key, DST_KEY_DS, &state);
 	if (result == ISC_R_SUCCESS) {
-		return (state == DST_KEY_STATE_RUMOURED ||
-			state == DST_KEY_STATE_OMNIPRESENT);
+		return state == DST_KEY_STATE_RUMOURED ||
+		       state == DST_KEY_STATE_OMNIPRESENT;
 	}
 
 	/* If no kasp state, check timings. */
@@ -705,7 +703,7 @@ syncpublish(dst_key_t *key, isc_stdtime_t now) {
 	if (result == ISC_R_SUCCESS && when < now) {
 		publish = false;
 	}
-	return (publish);
+	return publish;
 }
 
 /*%<
@@ -735,25 +733,25 @@ syncdelete(dst_key_t *key, isc_stdtime_t now) {
 	 * Smart signing started with key format 1.3.
 	 */
 	if (major == 1 && minor <= 2) {
-		return (false);
+		return false;
 	}
 
 	/* Check kasp state first. */
 	result = dst_key_getstate(key, DST_KEY_DS, &state);
 	if (result == ISC_R_SUCCESS) {
-		return (state == DST_KEY_STATE_UNRETENTIVE ||
-			state == DST_KEY_STATE_HIDDEN);
+		return state == DST_KEY_STATE_UNRETENTIVE ||
+		       state == DST_KEY_STATE_HIDDEN;
 	}
 
 	/* If no kasp state, check timings. */
 	result = dst_key_gettime(key, DST_TIME_SYNCDELETE, &when);
 	if (result != ISC_R_SUCCESS) {
-		return (false);
+		return false;
 	}
 	if (when <= now) {
-		return (true);
+		return true;
 	}
-	return (false);
+	return false;
 }
 
 #define is_zone_key(key) \
@@ -880,7 +878,7 @@ dns_dnssec_signmessage(dns_message_t *msg, dst_key_t *key) {
 	dns_rdatalist_tordataset(datalist, dataset);
 	msg->sig0 = dataset;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 failure:
 	if (dynbuf != NULL) {
@@ -893,7 +891,7 @@ failure:
 		dst_context_destroy(&ctx);
 	}
 
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -922,7 +920,7 @@ dns_dnssec_verifymessage(isc_buffer_t *source, dns_message_t *msg,
 
 	if (is_response(msg)) {
 		if (msg->query.base == NULL) {
-			return (DNS_R_UNEXPECTEDTSIG);
+			return DNS_R_UNEXPECTEDTSIG;
 		}
 	}
 
@@ -1025,7 +1023,7 @@ dns_dnssec_verifymessage(isc_buffer_t *source, dns_message_t *msg,
 	dst_context_destroy(&ctx);
 	dns_rdata_freestruct(&sig);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 failure:
 	if (signeedsfree) {
@@ -1035,7 +1033,7 @@ failure:
 		dst_context_destroy(&ctx);
 	}
 
-	return (result);
+	return result;
 }
 
 /*%
@@ -1055,8 +1053,8 @@ dns_dnssec_selfsigns(dns_rdata_t *rdata, const dns_name_t *name,
 		INSIST(sigrdataset->covers == dns_rdatatype_dnskey);
 	}
 
-	return (dns_dnssec_signs(rdata, name, rdataset, sigrdataset, ignoretime,
-				 mctx));
+	return dns_dnssec_signs(rdata, name, rdataset, sigrdataset, ignoretime,
+				mctx);
 }
 
 bool
@@ -1072,12 +1070,12 @@ dns_dnssec_signs(dns_rdata_t *rdata, const dns_name_t *name,
 
 	INSIST(sigrdataset->type == dns_rdatatype_rrsig);
 	if (sigrdataset->covers != rdataset->type) {
-		return (false);
+		return false;
 	}
 
 	result = dns_dnssec_keyfromrdata(name, rdata, mctx, &dstkey);
 	if (result != ISC_R_SUCCESS) {
-		return (false);
+		return false;
 	}
 	result = dns_rdata_tostruct(rdata, &key, NULL);
 	RUNTIME_CHECK(result == ISC_R_SUCCESS);
@@ -1097,12 +1095,12 @@ dns_dnssec_signs(dns_rdata_t *rdata, const dns_name_t *name,
 						   &sigrdata, NULL);
 			if (result == ISC_R_SUCCESS) {
 				dst_key_free(&dstkey);
-				return (true);
+				return true;
 			}
 		}
 	}
 	dst_key_free(&dstkey);
-	return (false);
+	return false;
 }
 
 void
@@ -1335,7 +1333,7 @@ failure:
 	if (dstkey != NULL) {
 		dst_key_free(&dstkey);
 	}
-	return (result);
+	return result;
 }
 
 /*%
@@ -1401,7 +1399,7 @@ failure:
 		dst_key_free(&key->key);
 		dns_dnsseckey_destroy(mctx, &key);
 	}
-	return (result);
+	return result;
 }
 
 /*%
@@ -1505,7 +1503,7 @@ mark_active_keys(dns_dnsseckeylist_t *keylist, dns_rdataset_t *rrsigs) {
 	if (dns_rdataset_isassociated(&sigs)) {
 		dns_rdataset_disassociate(&sigs);
 	}
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -1536,7 +1534,7 @@ keyfromfile(dns_kasp_t *kasp, const char *keydir, dst_key_t *key, int type,
 		}
 	}
 
-	return (result);
+	return result;
 }
 
 /*%
@@ -1735,7 +1733,7 @@ failure:
 	if (privkey != NULL) {
 		dst_key_free(&privkey);
 	}
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -1748,14 +1746,14 @@ dns_dnssec_make_dnskey(dst_key_t *key, unsigned char *buf, int bufsize,
 	isc_buffer_init(&b, buf, bufsize);
 	result = dst_key_todns(key, &b);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 
 	dns_rdata_reset(target);
 	isc_buffer_usedregion(&b, &r);
 	dns_rdata_fromregion(target, dst_key_class(key), dns_rdatatype_dnskey,
 			     &r);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -1769,7 +1767,7 @@ addrdata(dns_rdata_t *rdata, dns_diff_t *diff, const dns_name_t *origin,
 	dns_diff_appendminimal(diff, &tuple);
 
 failure:
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -1783,7 +1781,7 @@ delrdata(dns_rdata_t *rdata, dns_diff_t *diff, const dns_name_t *origin,
 	dns_diff_appendminimal(diff, &tuple);
 
 failure:
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -1818,7 +1816,7 @@ publish_key(dns_diff_t *diff, dns_dnsseckey_t *key, const dns_name_t *origin,
 	result = addrdata(&dnskey, diff, origin, ttl, mctx);
 
 failure:
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -1840,7 +1838,7 @@ remove_key(dns_diff_t *diff, dns_dnsseckey_t *key, const dns_name_t *origin,
 	result = delrdata(&dnskey, diff, origin, ttl, mctx);
 
 failure:
-	return (result);
+	return result;
 }
 
 static bool
@@ -1858,11 +1856,11 @@ exists(dns_rdataset_t *rdataset, dns_rdata_t *rdata) {
 		dns_rdataset_current(&trdataset, &current);
 		if (dns_rdata_compare(rdata, &current) == 0) {
 			dns_rdataset_disassociate(&trdataset);
-			return (true);
+			return true;
 		}
 	}
 	dns_rdataset_disassociate(&trdataset);
-	return (false);
+	return false;
 }
 
 static isc_result_t
@@ -1883,7 +1881,7 @@ add_cds(dns_dnsseckey_t *key, dns_rdata_t *keyrdata, const char *keystr,
 			      DNS_LOGMODULE_DNSSEC, ISC_LOG_ERROR,
 			      "build rdata CDS (%s) for key %s failed", algbuf,
 			      keystr);
-		return (r);
+		return r;
 	}
 
 	cdsrdata.type = dns_rdatatype_cds;
@@ -1897,7 +1895,7 @@ add_cds(dns_dnsseckey_t *key, dns_rdata_t *keyrdata, const char *keystr,
 			      keystr);
 		r = addrdata(&cdsrdata, diff, origin, ttl, mctx);
 	}
-	return (r);
+	return r;
 }
 
 static isc_result_t
@@ -1911,7 +1909,7 @@ delete_cds(dns_dnsseckey_t *key, dns_rdata_t *keyrdata, const char *keystr,
 
 	r = dns_ds_buildrdata(origin, keyrdata, digesttype, dsbuf, &cdsrdata);
 	if (r != ISC_R_SUCCESS) {
-		return (r);
+		return r;
 	}
 
 	cdsrdata.type = dns_rdatatype_cds;
@@ -1925,7 +1923,7 @@ delete_cds(dns_dnsseckey_t *key, dns_rdata_t *keyrdata, const char *keystr,
 			      keystr);
 		r = delrdata(&cdsrdata, diff, origin, cds->ttl, mctx);
 	}
-	return (r);
+	return r;
 }
 
 isc_result_t
@@ -2026,7 +2024,7 @@ dns_dnssec_syncupdate(dns_dnsseckeylist_t *keys, dns_dnsseckeylist_t *rmkeys,
 	if (!dns_rdataset_isassociated(cds) &&
 	    !dns_rdataset_isassociated(cdnskey))
 	{
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	/*
@@ -2069,7 +2067,7 @@ dns_dnssec_syncupdate(dns_dnsseckeylist_t *keys, dns_dnsseckeylist_t *rmkeys,
 	result = ISC_R_SUCCESS;
 
 failure:
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -2149,7 +2147,7 @@ dns_dnssec_syncdelete(dns_rdataset_t *cds, dns_rdataset_t *cdnskey,
 	result = ISC_R_SUCCESS;
 
 failure:
-	return (result);
+	return result;
 }
 
 /*
@@ -2389,7 +2387,7 @@ dns_dnssec_updatekeys(dns_dnsseckeylist_t *keys, dns_dnsseckeylist_t *newkeys,
 	result = ISC_R_SUCCESS;
 
 failure:
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -2437,5 +2435,5 @@ dns_dnssec_matchdskey(dns_name_t *name, dns_rdata_t *dsrdata,
 		result = ISC_R_NOTFOUND;
 	}
 
-	return (result);
+	return result;
 }
