@@ -185,6 +185,7 @@ struct dns_view {
 	unsigned int	      udpsize;
 	uint32_t	      maxrrperset;
 	uint32_t	      maxtypepername;
+	uint16_t	      max_queries;
 	uint8_t		      max_restarts;
 
 	/*
@@ -263,8 +264,9 @@ struct dns_view {
 #endif /* HAVE_LMDB */
 
 isc_result_t
-dns_view_create(isc_mem_t *mctx, dns_dispatchmgr_t *dispmgr,
-		dns_rdataclass_t rdclass, const char *name, dns_view_t **viewp);
+dns_view_create(isc_mem_t *mctx, isc_loopmgr_t *loopmgr,
+		dns_dispatchmgr_t *dispmgr, dns_rdataclass_t rdclass,
+		const char *name, dns_view_t **viewp);
 /*%<
  * Create a view.
  *
@@ -1340,4 +1342,16 @@ dns_view_setmaxrestarts(dns_view_t *view, uint8_t max_restarts);
  *\li	'max_restarts' is greater than 0.
  */
 
+void
+dns_view_setmaxqueries(dns_view_t *view, uint16_t max_queries);
+/*%
+ * Set the number of permissible outgoing queries before we give up.
+ * This defaults to 200.
+ *
+ * Requires:
+ *
+ *\li	'view' is valid;
+ *\li	'max_queries' is greater than 0.
+ */
+
 ISC_LANG_ENDDECLS
