@@ -179,7 +179,7 @@ fetch_done(void *arg) {
 		dns_db_detach(&resp->db);
 	}
 
-	isc_mem_putanddetach(&resp->mctx, resp, sizeof(*resp));
+	dns_resolver_freefresp(&resp);
 
 	switch (eresult) {
 	case ISC_R_SUCCESS:
@@ -241,8 +241,9 @@ checkbogus(void *arg) {
 	dns__nta_ref(nta); /* for dns_resolver_createfetch */
 	result = dns_resolver_createfetch(
 		resolver, &nta->name, dns_rdatatype_nsec, NULL, NULL, NULL,
-		NULL, 0, DNS_FETCHOPT_NONTA, 0, NULL, nta->loop, fetch_done,
-		nta, &nta->rdataset, &nta->sigrdataset, &nta->fetch);
+		NULL, 0, DNS_FETCHOPT_NONTA, 0, NULL, NULL, nta->loop,
+		fetch_done, nta, &nta->rdataset, &nta->sigrdataset,
+		&nta->fetch);
 	if (result != ISC_R_SUCCESS) {
 		dns__nta_detach(&nta); /* for dns_resolver_createfetch() */
 	}
@@ -305,7 +306,7 @@ dns_ntatable_add(dns_ntatable_t *ntatable, const dns_name_t *name, bool force,
 	REQUIRE(VALID_NTATABLE(ntatable));
 
 	if (atomic_load(&ntatable->shuttingdown)) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	RWLOCK(&ntatable->rwlock, isc_rwlocktype_write);
@@ -342,7 +343,7 @@ dns_ntatable_add(dns_ntatable_t *ntatable, const dns_name_t *name, bool force,
 	dns_qpmulti_commit(ntatable->table, &qp);
 	RWUNLOCK(&ntatable->rwlock, isc_rwlocktype_write);
 
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -364,7 +365,7 @@ dns_ntatable_delete(dns_ntatable_t *ntatable, const dns_name_t *name) {
 	dns_qp_compact(qp, DNS_QPGC_MAYBE);
 	dns_qpmulti_commit(ntatable->table, &qp);
 
-	return (result);
+	return result;
 }
 
 static void
@@ -447,7 +448,7 @@ dns_ntatable_covered(dns_ntatable_t *ntatable, isc_stdtime_t now,
 done:
 	RWUNLOCK(&ntatable->rwlock, isc_rwlocktype_read);
 	dns_qpread_destroy(ntatable->table, &qpr);
-	return (answer);
+	return answer;
 }
 
 static isc_result_t
@@ -456,11 +457,11 @@ putstr(isc_buffer_t **b, const char *str) {
 
 	result = isc_buffer_reserve(*b, strlen(str));
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 
 	isc_buffer_putstr(*b, str);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
@@ -517,7 +518,7 @@ dns_ntatable_totext(dns_ntatable_t *ntatable, const char *view,
 cleanup:
 	dns_qpread_destroy(ntatable->table, &qpr);
 	RWUNLOCK(&ntatable->rwlock, isc_rwlocktype_read);
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -575,7 +576,7 @@ dns_ntatable_save(dns_ntatable_t *ntatable, FILE *fp) {
 		result = ISC_R_NOTFOUND;
 	}
 
-	return (result);
+	return result;
 }
 
 static void
@@ -650,7 +651,7 @@ static size_t
 qp_makekey(dns_qpkey_t key, void *uctx ISC_ATTR_UNUSED, void *pval,
 	   uint32_t ival ISC_ATTR_UNUSED) {
 	dns__nta_t *nta = pval;
-	return (dns_qpkey_fromname(key, &nta->name));
+	return dns_qpkey_fromname(key, &nta->name);
 }
 
 static void
