@@ -97,8 +97,8 @@ findnsec3node(dns_db_t *db, const dns_name_t *name, bool create,
 
 	REQUIRE(VALID_RBTDB(rbtdb));
 
-	return (dns__rbtdb_findnodeintree(rbtdb, rbtdb->nsec3, name, create,
-					  nodep DNS__DB_FLARG_PASS));
+	return dns__rbtdb_findnodeintree(rbtdb, rbtdb->nsec3, name, create,
+					 nodep DNS__DB_FLARG_PASS);
 }
 
 static isc_result_t
@@ -119,7 +119,7 @@ zone_zonecut_callback(dns_rbtnode_t *node, dns_name_t *name,
 	 * zonecut.
 	 */
 	if (search->zonecut != NULL) {
-		return (result);
+		return result;
 	}
 
 	onode = search->rbtdb->origin_node;
@@ -247,7 +247,7 @@ zone_zonecut_callback(dns_rbtnode_t *node, dns_name_t *name,
 	NODE_UNLOCK(&(search->rbtdb->node_locks[node->locknum].lock),
 		    &nlocktype);
 
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -308,9 +308,9 @@ setup_delegation(rbtdb_search_t *search, dns_dbnode_t **nodep,
 	}
 
 	if (type == dns_rdatatype_dname) {
-		return (DNS_R_DNAME);
+		return DNS_R_DNAME;
 	}
-	return (DNS_R_DELEGATION);
+	return DNS_R_DELEGATION;
 }
 
 typedef enum { FORWARD, BACK } direction_t;
@@ -370,9 +370,9 @@ step(rbtdb_search_t *search, dns_rbtnodechain_t *chain, direction_t direction,
 		result = dns_name_concatenate(&prefix, origin, nextname, NULL);
 	}
 	if (result == ISC_R_SUCCESS) {
-		return (true);
+		return true;
 	}
-	return (false);
+	return false;
 }
 
 /*
@@ -390,10 +390,10 @@ activeempty(rbtdb_search_t *search, dns_rbtnodechain_t *chain,
 
 	result = dns_rbtnodechain_next(chain, NULL, NULL);
 	if (result != ISC_R_SUCCESS && result != DNS_R_NEWORIGIN) {
-		return (false);
+		return false;
 	}
-	return (step(search, chain, FORWARD, next) &&
-		dns_name_issubdomain(next, current));
+	return step(search, chain, FORWARD, next) &&
+	       dns_name_issubdomain(next, current);
 }
 
 static bool
@@ -440,7 +440,7 @@ wildcard_blocked(rbtdb_search_t *search, const dns_name_t *qname,
 
 	if (!check_prev && !check_next) {
 		/* No predecessor or successor was found at all? */
-		return (false);
+		return false;
 	}
 
 	dns_name_clone(qname, &rname);
@@ -455,7 +455,7 @@ wildcard_blocked(rbtdb_search_t *search, const dns_name_t *qname,
 		if ((check_prev && dns_name_issubdomain(prev, &rname)) ||
 		    (check_next && dns_name_issubdomain(next, &rname)))
 		{
-			return (true);
+			return true;
 		}
 
 		/*
@@ -465,7 +465,7 @@ wildcard_blocked(rbtdb_search_t *search, const dns_name_t *qname,
 		dns_name_getlabelsequence(&rname, 1, n - 1, &rname);
 	} while (!dns_name_equal(&rname, &tname));
 
-	return (false);
+	return false;
 }
 
 static isc_result_t
@@ -587,7 +587,7 @@ find_wildcard(rbtdb_search_t *search, dns_rbtnode_t **nodep,
 					if (wildcard_blocked(search, qname,
 							     wname))
 					{
-						return (ISC_R_NOTFOUND);
+						return ISC_R_NOTFOUND;
 					}
 					/*
 					 * The wildcard node is active!
@@ -626,7 +626,7 @@ find_wildcard(rbtdb_search_t *search, dns_rbtnode_t **nodep,
 		}
 	} while (!done);
 
-	return (result);
+	return result;
 }
 
 static bool
@@ -660,11 +660,11 @@ matchparams(dns_slabheader_t *header, rbtdb_search_t *search) {
 		    memcmp(nsec3.salt, search->rbtversion->salt,
 			   nsec3.salt_length) == 0)
 		{
-			return (true);
+			return true;
 		}
 		dns_rdata_reset(&rdata);
 	}
-	return (false);
+	return false;
 }
 
 /*
@@ -686,11 +686,11 @@ previous_closest_nsec(dns_rdatatype_t type, rbtdb_search_t *search,
 	if (type == dns_rdatatype_nsec3) {
 		result = dns_rbtnodechain_prev(&search->chain, NULL, NULL);
 		if (result != ISC_R_SUCCESS && result != DNS_R_NEWORIGIN) {
-			return (result);
+			return result;
 		}
 		result = dns_rbtnodechain_current(&search->chain, name, origin,
 						  nodep);
-		return (result);
+		return result;
 	}
 
 	target = dns_fixedname_initname(&ftarget);
@@ -706,7 +706,7 @@ previous_closest_nsec(dns_rdatatype_t type, rbtdb_search_t *search,
 			result = dns_name_concatenate(name, origin, target,
 						      NULL);
 			if (result != ISC_R_SUCCESS) {
-				return (result);
+				return result;
 			}
 			nsecnode = NULL;
 			result = dns_rbt_findnode(
@@ -748,7 +748,7 @@ previous_closest_nsec(dns_rdatatype_t type, rbtdb_search_t *search,
 			}
 		}
 		if (result != ISC_R_SUCCESS) {
-			return (result);
+			return result;
 		}
 
 		/*
@@ -756,7 +756,7 @@ previous_closest_nsec(dns_rdatatype_t type, rbtdb_search_t *search,
 		 */
 		result = dns_name_concatenate(name, origin, target, NULL);
 		if (result != ISC_R_SUCCESS) {
-			return (result);
+			return result;
 		}
 
 		*nodep = NULL;
@@ -764,7 +764,7 @@ previous_closest_nsec(dns_rdatatype_t type, rbtdb_search_t *search,
 					  nodep, &search->chain,
 					  DNS_RBTFIND_EMPTYDATA, NULL, NULL);
 		if (result == ISC_R_SUCCESS) {
-			return (result);
+			return result;
 		}
 
 		/*
@@ -777,7 +777,7 @@ previous_closest_nsec(dns_rdatatype_t type, rbtdb_search_t *search,
 				      DNS_LOGMODULE_CACHE, ISC_LOG_ERROR,
 				      "previous_closest_nsec(): %s",
 				      isc_result_totext(result));
-			return (DNS_R_BADDB);
+			return DNS_R_BADDB;
 		}
 	}
 }
@@ -826,7 +826,7 @@ again:
 	prevnode = NULL;
 	result = dns_rbtnodechain_current(&search->chain, name, origin, &node);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 	do {
 		dns_slabheader_t *found = NULL, *foundsig = NULL;
@@ -979,7 +979,7 @@ again:
 		result = DNS_R_BADDB;
 	}
 
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -1095,11 +1095,7 @@ zone_find(dns_db_t *db, const dns_name_t *name, dns_dbversion_t *version,
 						: DNS_R_NXDOMAIN;
 			}
 		} else {
-			bool wantpartial = (options & DNS_DBFIND_WANTPARTIAL) !=
-					   0;
-			result = active	       ? DNS_R_EMPTYNAME
-				 : wantpartial ? DNS_R_PARTIALMATCH
-					       : DNS_R_NXDOMAIN;
+			result = active ? DNS_R_EMPTYNAME : DNS_R_NXDOMAIN;
 		}
 		goto tree_exit;
 	} else if (result != ISC_R_SUCCESS) {
@@ -1380,8 +1376,7 @@ found:
 					  nlocktype DNS__DB_FLARG_PASS);
 			*nodep = node;
 		}
-		if ((search.rbtversion->secure &&
-		     !search.rbtversion->havensec3))
+		if (search.rbtversion->secure && !search.rbtversion->havensec3)
 		{
 			dns__rbtdb_bindrdataset(search.rbtdb, node, nsecheader,
 						0, nlocktype,
@@ -1497,7 +1492,7 @@ tree_exit:
 
 	dns_rbtnodechain_reset(&search.chain);
 
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -1590,10 +1585,10 @@ zone_findrdataset(dns_db_t *db, dns_dbnode_t *node, dns_dbversion_t *version,
 	}
 
 	if (found == NULL) {
-		return (ISC_R_NOTFOUND);
+		return ISC_R_NOTFOUND;
 	}
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static bool
@@ -1602,9 +1597,9 @@ delegating_type(dns_rbtdb_t *rbtdb, dns_rbtnode_t *node, dns_typepair_t type) {
 	    (type == dns_rdatatype_ns &&
 	     (node != rbtdb->origin_node || IS_STUB(rbtdb))))
 	{
-		return (true);
+		return true;
 	}
-	return (false);
+	return false;
 }
 
 /*
@@ -1683,7 +1678,7 @@ done:
 		*nodep = node;
 	}
 
-	return (noderesult);
+	return noderesult;
 }
 
 static isc_result_t
@@ -1705,7 +1700,7 @@ loading_addrdataset(void *arg, const dns_name_t *name,
 	if (rdataset->type == dns_rdatatype_soa &&
 	    !dns_name_equal(name, &rbtdb->common.origin))
 	{
-		return (DNS_R_NOTZONETOP);
+		return DNS_R_NOTZONETOP;
 	}
 
 	if (rdataset->type != dns_rdatatype_nsec3 &&
@@ -1719,17 +1714,17 @@ loading_addrdataset(void *arg, const dns_name_t *name,
 		 * NS record owners cannot legally be wild cards.
 		 */
 		if (rdataset->type == dns_rdatatype_ns) {
-			return (DNS_R_INVALIDNS);
+			return DNS_R_INVALIDNS;
 		}
 		/*
 		 * NSEC3 record owners cannot legally be wild cards.
 		 */
 		if (rdataset->type == dns_rdatatype_nsec3) {
-			return (DNS_R_INVALIDNSEC3);
+			return DNS_R_INVALIDNSEC3;
 		}
 		result = dns__zonerbt_wildcardmagic(rbtdb, name, false);
 		if (result != ISC_R_SUCCESS) {
-			return (result);
+			return result;
 		}
 	}
 
@@ -1746,7 +1741,7 @@ loading_addrdataset(void *arg, const dns_name_t *name,
 		result = loadnode(rbtdb, name, &node, false);
 	}
 	if (result != ISC_R_SUCCESS && result != ISC_R_EXISTS) {
-		return (result);
+		return result;
 	}
 	if (result == ISC_R_SUCCESS) {
 		node->locknum = node->hashval % rbtdb->node_lock_count;
@@ -1756,7 +1751,12 @@ loading_addrdataset(void *arg, const dns_name_t *name,
 					    &region, sizeof(dns_slabheader_t),
 					    rbtdb->maxrrperset);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		if (result == DNS_R_TOOMANYRECORDS) {
+			dns__db_logtoomanyrecords((dns_db_t *)rbtdb, name,
+						  rdataset->type, "adding",
+						  rbtdb->maxrrperset);
+		}
+		return result;
 	}
 	newheader = (dns_slabheader_t *)region.base;
 	*newheader = (dns_slabheader_t){
@@ -1793,7 +1793,7 @@ loading_addrdataset(void *arg, const dns_name_t *name,
 		result = ISC_R_SUCCESS;
 	}
 
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -1820,7 +1820,7 @@ beginload(dns_db_t *db, dns_rdatacallbacks_t *callbacks) {
 	callbacks->add = loading_addrdataset;
 	callbacks->add_private = loadctx;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -1859,7 +1859,7 @@ endload(dns_db_t *db, dns_rdatacallbacks_t *callbacks) {
 
 	isc_mem_put(rbtdb->common.mctx, loadctx, sizeof(*loadctx));
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static bool
@@ -1873,7 +1873,7 @@ issecure(dns_db_t *db) {
 	secure = rbtdb->current_version->secure;
 	RWUNLOCK(&rbtdb->lock, isc_rwlocktype_read);
 
-	return (secure);
+	return secure;
 }
 
 static isc_result_t
@@ -1914,7 +1914,7 @@ getnsec3parameters(dns_db_t *db, dns_dbversion_t *version, dns_hash_t *hash,
 	}
 	RWUNLOCK(&rbtdb->lock, isc_rwlocktype_read);
 
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -1939,7 +1939,7 @@ getsize(dns_db_t *db, dns_dbversion_t *version, uint64_t *records,
 	RWUNLOCK(&rbtversion->rwlock, isc_rwlocktype_read);
 	RWUNLOCK(&rbtdb->lock, isc_rwlocktype_read);
 
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -1994,7 +1994,7 @@ setsigningtime(dns_db_t *db, dns_rdataset_t *rdataset, isc_stdtime_t resign) {
 	}
 	NODE_UNLOCK(&rbtdb->node_locks[RBTDB_HEADERNODE(header)->locknum].lock,
 		    &nlocktype);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -2076,7 +2076,7 @@ getsigningtime(dns_db_t *db, isc_stdtime_t *resign, dns_name_t *foundname,
 
 	TREE_UNLOCK(&rbtdb->tree_lock, &tlocktype);
 
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -2088,18 +2088,7 @@ setgluecachestats(dns_db_t *db, isc_stats_t *stats) {
 	REQUIRE(stats != NULL);
 
 	isc_stats_attach(stats, &rbtdb->gluecachestats);
-	return (ISC_R_SUCCESS);
-}
-
-static dns_glue_t *
-new_gluelist(isc_mem_t *mctx, dns_name_t *name) {
-	dns_glue_t *glue = isc_mem_get(mctx, sizeof(*glue));
-	*glue = (dns_glue_t){ 0 };
-	dns_name_t *gluename = dns_fixedname_initname(&glue->fixedname);
-
-	dns_name_copy(name, gluename);
-
-	return (glue);
+	return ISC_R_SUCCESS;
 }
 
 static isc_result_t
@@ -2116,6 +2105,8 @@ glue_nsdname_cb(void *arg, const dns_name_t *name, dns_rdatatype_t qtype,
 	dns_rdataset_t rdataset_aaaa, sigrdataset_aaaa;
 	dns_rbtnode_t *node_aaaa = NULL;
 	dns_glue_t *glue = NULL;
+	dns_fixedname_t f_nodename;
+	dns_name_t *nodename = dns_fixedname_initname(&f_nodename);
 
 	UNUSED(unused);
 
@@ -2126,6 +2117,8 @@ glue_nsdname_cb(void *arg, const dns_name_t *name, dns_rdatatype_t qtype,
 
 	ctx = (dns_glue_additionaldata_ctx_t *)arg;
 
+	dns__rbtdb_nodefullname(ctx->db, ctx->node, nodename);
+
 	name_a = dns_fixedname_initname(&fixedname_a);
 	dns_rdataset_init(&rdataset_a);
 	dns_rdataset_init(&sigrdataset_a);
@@ -2139,7 +2132,7 @@ glue_nsdname_cb(void *arg, const dns_name_t *name, dns_rdatatype_t qtype,
 			   name_a, &rdataset_a,
 			   &sigrdataset_a DNS__DB_FLARG_PASS);
 	if (result == DNS_R_GLUE) {
-		glue = new_gluelist(ctx->db->mctx, name_a);
+		glue = dns__db_new_glue(ctx->db->mctx, name_a);
 
 		dns_rdataset_init(&glue->rdataset_a);
 		dns_rdataset_init(&glue->sigrdataset_a);
@@ -2159,7 +2152,7 @@ glue_nsdname_cb(void *arg, const dns_name_t *name, dns_rdatatype_t qtype,
 			   &sigrdataset_aaaa DNS__DB_FLARG_PASS);
 	if (result == DNS_R_GLUE) {
 		if (glue == NULL) {
-			glue = new_gluelist(ctx->db->mctx, name_aaaa);
+			glue = dns__db_new_glue(ctx->db->mctx, name_aaaa);
 
 			dns_rdataset_init(&glue->rdataset_a);
 			dns_rdataset_init(&glue->sigrdataset_a);
@@ -2185,7 +2178,10 @@ glue_nsdname_cb(void *arg, const dns_name_t *name, dns_rdatatype_t qtype,
 	 * attributes for the first rdataset associated with the first name
 	 * added to the ADDITIONAL section.
 	 */
-	if (glue != NULL && dns_name_issubdomain(name, ctx->nodename)) {
+	isc_result_t dns_rbt_fullnamefromnode(dns_rbtnode_t * node,
+					      dns_name_t * name);
+
+	if (glue != NULL && dns_name_issubdomain(name, nodename)) {
 		if (dns_rdataset_isassociated(&glue->rdataset_a)) {
 			glue->rdataset_a.attributes |=
 				DNS_RDATASETATTR_REQUIRED;
@@ -2197,8 +2193,8 @@ glue_nsdname_cb(void *arg, const dns_name_t *name, dns_rdatatype_t qtype,
 	}
 
 	if (glue != NULL) {
-		glue->next = ctx->glue_list;
-		ctx->glue_list = glue;
+		glue->next = ctx->glue;
+		ctx->glue = glue;
 	}
 
 	result = ISC_R_SUCCESS;
@@ -2226,224 +2222,34 @@ glue_nsdname_cb(void *arg, const dns_name_t *name, dns_rdatatype_t qtype,
 			ctx->db, (dns_dbnode_t *)&node_aaaa DNS__DB_FLARG_PASS);
 	}
 
-	return (result);
+	return result;
 }
 
-#define IS_REQUIRED_GLUE(r) (((r)->attributes & DNS_RDATASETATTR_REQUIRED) != 0)
-
-static void
-addglue_to_message(dns_glue_t *ge, dns_message_t *msg) {
-	for (; ge != NULL; ge = ge->next) {
-		dns_name_t *name = NULL;
-		dns_rdataset_t *rdataset_a = NULL;
-		dns_rdataset_t *sigrdataset_a = NULL;
-		dns_rdataset_t *rdataset_aaaa = NULL;
-		dns_rdataset_t *sigrdataset_aaaa = NULL;
-		dns_name_t *gluename = dns_fixedname_name(&ge->fixedname);
-		bool prepend_name = false;
-
-		dns_message_gettempname(msg, &name);
-
-		dns_name_copy(gluename, name);
-
-		if (dns_rdataset_isassociated(&ge->rdataset_a)) {
-			dns_message_gettemprdataset(msg, &rdataset_a);
-		}
-
-		if (dns_rdataset_isassociated(&ge->sigrdataset_a)) {
-			dns_message_gettemprdataset(msg, &sigrdataset_a);
-		}
-
-		if (dns_rdataset_isassociated(&ge->rdataset_aaaa)) {
-			dns_message_gettemprdataset(msg, &rdataset_aaaa);
-		}
-
-		if (dns_rdataset_isassociated(&ge->sigrdataset_aaaa)) {
-			dns_message_gettemprdataset(msg, &sigrdataset_aaaa);
-		}
-
-		if (rdataset_a != NULL) {
-			dns_rdataset_clone(&ge->rdataset_a, rdataset_a);
-			ISC_LIST_APPEND(name->list, rdataset_a, link);
-			if (IS_REQUIRED_GLUE(rdataset_a)) {
-				prepend_name = true;
-			}
-		}
-
-		if (sigrdataset_a != NULL) {
-			dns_rdataset_clone(&ge->sigrdataset_a, sigrdataset_a);
-			ISC_LIST_APPEND(name->list, sigrdataset_a, link);
-		}
-
-		if (rdataset_aaaa != NULL) {
-			dns_rdataset_clone(&ge->rdataset_aaaa, rdataset_aaaa);
-			ISC_LIST_APPEND(name->list, rdataset_aaaa, link);
-			if (IS_REQUIRED_GLUE(rdataset_aaaa)) {
-				prepend_name = true;
-			}
-		}
-		if (sigrdataset_aaaa != NULL) {
-			dns_rdataset_clone(&ge->sigrdataset_aaaa,
-					   sigrdataset_aaaa);
-			ISC_LIST_APPEND(name->list, sigrdataset_aaaa, link);
-		}
-
-		dns_message_addname(msg, name, DNS_SECTION_ADDITIONAL);
-
-		/*
-		 * When looking for required glue, dns_message_rendersection()
-		 * only processes the first rdataset associated with the first
-		 * name added to the ADDITIONAL section.  dns_message_addname()
-		 * performs an append on the list of names in a given section,
-		 * so if any glue record was marked as required, we need to
-		 * move the name it is associated with to the beginning of the
-		 * list for the ADDITIONAL section or else required glue might
-		 * not be rendered.
-		 */
-		if (prepend_name) {
-			ISC_LIST_UNLINK(msg->sections[DNS_SECTION_ADDITIONAL],
-					name, link);
-			ISC_LIST_PREPEND(msg->sections[DNS_SECTION_ADDITIONAL],
-					 name, link);
-		}
-	}
-}
-
-static dns_glue_t *
-newglue(dns_db_t *db, dns_dbversion_t *dbversion, dns_rbtnode_t *node,
-	dns_rdataset_t *rdataset) {
-	dns_fixedname_t nodename;
-	dns_glue_additionaldata_ctx_t ctx = {
-		.db = db,
-		.version = dbversion,
-		.nodename = dns_fixedname_initname(&nodename),
-	};
-
-	/*
-	 * Get the owner name of the NS RRset - it will be necessary for
-	 * identifying required glue in glue_nsdname_cb() (by
-	 * determining which NS records in the delegation are
-	 * in-bailiwick).
-	 */
-	dns__rbtdb_nodefullname(db, node, ctx.nodename);
-
-	(void)dns_rdataset_additionaldata(rdataset, dns_rootname,
-					  glue_nsdname_cb, &ctx);
-
-	return (ctx.glue_list);
-}
-
-/* FIXME: Perhaps we can squash dns_gluenode_t with
- * dns_glue_additionaldata_ctx_t */
-
-static dns_gluenode_t *
-new_gluenode(dns_db_t *db, dns_dbversion_t *dbversion, dns_rbtnode_t *node,
-	     dns_rdataset_t *rdataset) {
-	dns_gluenode_t *gluenode = isc_mem_get(db->mctx, sizeof(*gluenode));
-	*gluenode = (dns_gluenode_t){
-		.glue = newglue(db, dbversion, node, rdataset),
-		.db = db,
-	};
-
-	isc_mem_attach(db->mctx, &gluenode->mctx);
-	dns_db_attachnode(db, node, (dns_dbnode_t **)&gluenode->node);
-
-	return (gluenode);
-}
-
-static uint32_t
-rbtnode_hash(const dns_rbtnode_t *node) {
-	return (isc_hash32(&node, sizeof(node), true));
-}
-
-static int
-rbtnode_match(struct cds_lfht_node *ht_node, const void *key) {
-	const dns_gluenode_t *gluenode =
-		caa_container_of(ht_node, dns_gluenode_t, ht_node);
-	const dns_rbtnode_t *node = key;
-
-	return (gluenode->node == node);
-}
-
-static uint32_t
-gluenode_hash(const dns_gluenode_t *gluenode) {
-	return (rbtnode_hash(gluenode->node));
-}
-
-static int
-gluenode_match(struct cds_lfht_node *ht_node, const void *key) {
-	const dns_gluenode_t *gluenode = key;
-
-	return (rbtnode_match(ht_node, gluenode->node));
-}
-
-static void
+static isc_result_t
 addglue(dns_db_t *db, dns_dbversion_t *dbversion, dns_rdataset_t *rdataset,
 	dns_message_t *msg) {
 	dns_rbtdb_t *rbtdb = (dns_rbtdb_t *)db;
-	dns_rbtdb_version_t *version = dbversion;
-	dns_rbtnode_t *node = (dns_rbtnode_t *)rdataset->slab.node;
-	dns_gluenode_t *gluenode = NULL;
+	dns_rbtdb_version_t *rbtversion = dbversion;
+	isc_result_t result;
 
 	REQUIRE(rdataset->type == dns_rdatatype_ns);
 	REQUIRE(rbtdb == (dns_rbtdb_t *)rdataset->slab.db);
-	REQUIRE(rbtdb == version->rbtdb);
+	REQUIRE(rbtdb == rbtversion->rbtdb);
 	REQUIRE(!IS_CACHE(rbtdb) && !IS_STUB(rbtdb));
 
-	/*
-	 * The glue table cache that forms a part of the DB version
-	 * structure is not explicitly bounded and there's no cache
-	 * cleaning. The zone data size itself is an implicit bound.
-	 *
-	 * The key into the glue hashtable is the node pointer. This is
-	 * because the glue hashtable is a property of the DB version,
-	 * and the glue is keyed for the ownername/NS tuple. We don't
-	 * bother with using an expensive dns_name_t comparison here as
-	 * the node pointer is a fixed value that won't change for a DB
-	 * version and can be compared directly.
-	 */
-
-	rcu_read_lock();
-
-	struct cds_lfht_iter iter;
-	cds_lfht_lookup(version->glue_table, rbtnode_hash(node), rbtnode_match,
-			node, &iter);
-
-	gluenode = cds_lfht_entry(cds_lfht_iter_get_node(&iter), dns_gluenode_t,
-				  ht_node);
-	if (gluenode == NULL) {
-		/* No cached glue was found in the table. Get new glue. */
-		gluenode = new_gluenode(db, version, node, rdataset);
-
-		struct cds_lfht_node *ht_node = cds_lfht_add_unique(
-			version->glue_table, gluenode_hash(gluenode),
-			gluenode_match, gluenode, &gluenode->ht_node);
-
-		if (ht_node != &gluenode->ht_node) {
-			dns__rbtdb_free_gluenode_rcu(&gluenode->rcu_head);
-
-			gluenode = cds_lfht_entry(ht_node, dns_gluenode_t,
-						  ht_node);
-		}
-	}
-
-	INSIST(gluenode != NULL);
-
-	dns_glue_t *glue = gluenode->glue;
-	isc_statscounter_t counter = dns_gluecachestatscounter_hits_present;
-
-	if (glue != NULL) {
-		/* We have a cached result. Add it to the message and return. */
-		addglue_to_message(glue, msg);
-	} else {
-		counter = dns_gluecachestatscounter_hits_absent;
-	}
-
-	rcu_read_unlock();
+	result = dns__db_addglue(db, dbversion, rdataset, msg, glue_nsdname_cb,
+				 &rbtversion->glue_stack);
 
 	if (rbtdb->gluecachestats != NULL) {
+		isc_statscounter_t counter =
+			(result == ISC_R_SUCCESS)
+				? dns_gluecachestatscounter_hits_present
+				: dns_gluecachestatscounter_hits_absent;
+
 		isc_stats_increment(rbtdb->gluecachestats, counter);
 	}
+
+	return ISC_R_SUCCESS;
 }
 
 dns_dbmethods_t dns__rbtdb_zonemethods = {
@@ -2530,7 +2336,7 @@ dns__zonerbt_wildcardmagic(dns_rbtdb_t *rbtdb, const dns_name_t *name,
 	dns_name_getlabelsequence(name, 1, n, &foundname);
 	result = dns_rbt_addnode(rbtdb->tree, &foundname, &node);
 	if (result != ISC_R_SUCCESS && result != ISC_R_EXISTS) {
-		return (result);
+		return result;
 	}
 	if (result == ISC_R_SUCCESS) {
 		node->nsec = DNS_DB_NSEC_NORMAL;
@@ -2543,7 +2349,7 @@ dns__zonerbt_wildcardmagic(dns_rbtdb_t *rbtdb, const dns_name_t *name,
 	if (lock) {
 		NODE_UNLOCK(&rbtdb->node_locks[node->locknum].lock, &nlocktype);
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 isc_result_t
@@ -2565,12 +2371,12 @@ dns__zonerbt_addwildcards(dns_rbtdb_t *rbtdb, const dns_name_t *name,
 			result = dns__zonerbt_wildcardmagic(rbtdb, &foundname,
 							    lock);
 			if (result != ISC_R_SUCCESS) {
-				return (result);
+				return result;
 			}
 			result = dns_rbt_addnode(rbtdb->tree, &foundname,
 						 &node);
 			if (result != ISC_R_SUCCESS && result != ISC_R_EXISTS) {
-				return (result);
+				return result;
 			}
 			if (result == ISC_R_SUCCESS) {
 				node->nsec = DNS_DB_NSEC_NORMAL;
@@ -2578,5 +2384,5 @@ dns__zonerbt_addwildcards(dns_rbtdb_t *rbtdb, const dns_name_t *name,
 		}
 		i++;
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
