@@ -247,10 +247,10 @@ cfg_parse_obj(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 
 	result = type->parse(pctx, type, ret);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 	ENSURE(*ret != NULL);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 void
@@ -307,13 +307,13 @@ cfg_create_tuple(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 		obj->value.tuple[i] = NULL;
 	}
 	*ret = obj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	if (obj != NULL) {
 		isc_mem_put(pctx->mctx, obj, sizeof(*obj));
 	}
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -336,11 +336,11 @@ cfg_parse_tuple(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	}
 
 	*ret = obj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	CLEANUP_OBJ(obj);
-	return (result);
+	return result;
 }
 
 void
@@ -408,7 +408,7 @@ free_tuple(cfg_parser_t *pctx, cfg_obj_t *obj) {
 bool
 cfg_obj_istuple(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_tuple);
+	return obj->type->rep == &cfg_rep_tuple;
 }
 
 const cfg_obj_t *
@@ -423,7 +423,7 @@ cfg_tuple_get(const cfg_obj_t *tupleobj, const char *name) {
 	fields = tupleobj->type->of;
 	for (f = fields, i = 0; f->name != NULL; f++, i++) {
 		if (strcmp(f->name, name) == 0) {
-			return (tupleobj->value.tuple[i]);
+			return tupleobj->value.tuple[i];
 		}
 	}
 	UNREACHABLE();
@@ -439,13 +439,13 @@ cfg_parse_special(cfg_parser_t *pctx, int special) {
 	if (pctx->token.type == isc_tokentype_special &&
 	    pctx->token.value.as_char == special)
 	{
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	cfg_parser_error(pctx, CFG_LOG_NEAR, "'%c' expected", special);
-	return (ISC_R_UNEXPECTEDTOKEN);
+	return ISC_R_UNEXPECTEDTOKEN;
 cleanup:
-	return (result);
+	return result;
 }
 
 /*
@@ -463,13 +463,13 @@ parse_semicolon(cfg_parser_t *pctx) {
 	if (pctx->token.type == isc_tokentype_special &&
 	    pctx->token.value.as_char == ';')
 	{
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	cfg_parser_error(pctx, CFG_LOG_BEFORE, "missing ';'");
 	cfg_ungettoken(pctx);
 cleanup:
-	return (result);
+	return result;
 }
 
 /*
@@ -482,13 +482,13 @@ parse_eof(cfg_parser_t *pctx) {
 	CHECK(cfg_gettoken(pctx, 0));
 
 	if (pctx->token.type == isc_tokentype_eof) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	cfg_parser_error(pctx, CFG_LOG_NEAR, "syntax error");
-	return (ISC_R_UNEXPECTEDTOKEN);
+	return ISC_R_UNEXPECTEDTOKEN;
 cleanup:
-	return (result);
+	return result;
 }
 
 /* A list of files, used internally for pctx->files. */
@@ -547,7 +547,7 @@ cfg_parser_create(isc_mem_t *mctx, isc_log_t *lctx, cfg_parser_t **ret) {
 	CHECK(cfg_create_list(pctx, &cfg_type_filelist, &pctx->closed_files));
 
 	*ret = pctx;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	if (pctx->lexer != NULL) {
@@ -556,7 +556,7 @@ cleanup:
 	CLEANUP_OBJ(pctx->open_files);
 	CLEANUP_OBJ(pctx->closed_files);
 	isc_mem_putanddetach(&pctx->mctx, pctx, sizeof(*pctx));
-	return (result);
+	return result;
 }
 
 void
@@ -588,10 +588,10 @@ parser_openfile(cfg_parser_t *pctx, const char *filename) {
 	elt->obj = stringobj;
 	ISC_LIST_APPEND(pctx->open_files->value.list, elt, link);
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 cleanup:
 	CLEANUP_OBJ(stringobj);
-	return (result);
+	return result;
 }
 
 void
@@ -647,11 +647,11 @@ parse2(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	CHECK(parse_eof(pctx));
 
 	*ret = obj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	CLEANUP_OBJ(obj);
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -676,7 +676,7 @@ cfg_parse_file(cfg_parser_t *pctx, const char *filename, const cfg_type_t *type,
 	ISC_LIST_APPEND(pctx->closed_files->value.list, elt, link);
 
 cleanup:
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -705,7 +705,7 @@ cfg_parse_buffer(cfg_parser_t *pctx, isc_buffer_t *buffer, const char *file,
 	pctx->buf_name = NULL;
 
 cleanup:
-	return (result);
+	return result;
 }
 
 void
@@ -748,7 +748,7 @@ cfg_parse_void(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 
 	UNUSED(type);
 
-	return (cfg_create_obj(pctx, &cfg_type_void, ret));
+	return cfg_create_obj(pctx, &cfg_type_void, ret);
 }
 
 void
@@ -772,7 +772,7 @@ cfg_doc_void(cfg_printer_t *pctx, const cfg_type_t *type) {
 bool
 cfg_obj_isvoid(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_void);
+	return obj->type->rep == &cfg_rep_void;
 }
 
 cfg_type_t cfg_type_void = { "void",	   cfg_parse_void, cfg_print_void,
@@ -797,13 +797,13 @@ cfg_parse_percentage(cfg_parser_t *pctx, const cfg_type_t *type,
 	CHECK(cfg_gettoken(pctx, 0));
 	if (pctx->token.type != isc_tokentype_string) {
 		cfg_parser_error(pctx, CFG_LOG_NEAR, "expected percentage");
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
 
 	percent = strtoull(TOKEN_STRING(pctx), &endp, 10);
 	if (*endp != '%' || *(endp + 1) != 0) {
 		cfg_parser_error(pctx, CFG_LOG_NEAR, "expected percentage");
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
 
 	CHECK(cfg_create_obj(pctx, &cfg_type_percentage, &obj));
@@ -811,7 +811,7 @@ cfg_parse_percentage(cfg_parser_t *pctx, const cfg_type_t *type,
 	*ret = obj;
 
 cleanup:
-	return (result);
+	return result;
 }
 
 void
@@ -830,7 +830,7 @@ cfg_print_percentage(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 uint32_t
 cfg_obj_aspercentage(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL && obj->type->rep == &cfg_rep_percentage);
-	return (obj->value.uint32);
+	return obj->value.uint32;
 }
 
 cfg_type_t cfg_type_percentage = { "percentage",	 cfg_parse_percentage,
@@ -840,7 +840,7 @@ cfg_type_t cfg_type_percentage = { "percentage",	 cfg_parse_percentage,
 bool
 cfg_obj_ispercentage(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_percentage);
+	return obj->type->rep == &cfg_rep_percentage;
 }
 
 /*
@@ -863,7 +863,7 @@ cfg_parse_fixedpoint(cfg_parser_t *pctx, const cfg_type_t *type,
 	if (pctx->token.type != isc_tokentype_string) {
 		cfg_parser_error(pctx, CFG_LOG_NEAR,
 				 "expected fixed point number");
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
 
 	p = TOKEN_STRING(pctx);
@@ -876,7 +876,7 @@ cfg_parse_fixedpoint(cfg_parser_t *pctx, const cfg_type_t *type,
 	{
 		cfg_parser_error(pctx, CFG_LOG_NEAR,
 				 "expected fixed point number");
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
 
 	CHECK(cfg_create_obj(pctx, &cfg_type_fixedpoint, &obj));
@@ -893,7 +893,7 @@ cfg_parse_fixedpoint(cfg_parser_t *pctx, const cfg_type_t *type,
 	*ret = obj;
 
 cleanup:
-	return (result);
+	return result;
 }
 
 void
@@ -913,7 +913,7 @@ cfg_print_fixedpoint(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 uint32_t
 cfg_obj_asfixedpoint(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL && obj->type->rep == &cfg_rep_fixedpoint);
-	return (obj->value.uint32);
+	return obj->value.uint32;
 }
 
 cfg_type_t cfg_type_fixedpoint = { "fixedpoint",	 cfg_parse_fixedpoint,
@@ -923,7 +923,7 @@ cfg_type_t cfg_type_fixedpoint = { "fixedpoint",	 cfg_parse_fixedpoint,
 bool
 cfg_obj_isfixedpoint(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_fixedpoint);
+	return obj->type->rep == &cfg_rep_fixedpoint;
 }
 
 /*
@@ -942,7 +942,7 @@ cfg_parse_uint32(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	CHECK(cfg_gettoken(pctx, ISC_LEXOPT_NUMBER | ISC_LEXOPT_CNUMBER));
 	if (pctx->token.type != isc_tokentype_number) {
 		cfg_parser_error(pctx, CFG_LOG_NEAR, "expected number");
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
 
 	CHECK(cfg_create_obj(pctx, &cfg_type_uint32, &obj));
@@ -950,7 +950,7 @@ cfg_parse_uint32(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	obj->value.uint32 = pctx->token.value.as_ulong;
 	*ret = obj;
 cleanup:
-	return (result);
+	return result;
 }
 
 void
@@ -974,13 +974,13 @@ cfg_print_uint32(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 bool
 cfg_obj_isuint32(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_uint32);
+	return obj->type->rep == &cfg_rep_uint32;
 }
 
 uint32_t
 cfg_obj_asuint32(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL && obj->type->rep == &cfg_rep_uint32);
-	return (obj->value.uint32);
+	return obj->value.uint32;
 }
 
 cfg_type_t cfg_type_uint32 = { "integer",	 cfg_parse_uint32,
@@ -993,13 +993,13 @@ cfg_type_t cfg_type_uint32 = { "integer",	 cfg_parse_uint32,
 bool
 cfg_obj_isuint64(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_uint64);
+	return obj->type->rep == &cfg_rep_uint64;
 }
 
 uint64_t
 cfg_obj_asuint64(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL && obj->type->rep == &cfg_rep_uint64);
-	return (obj->value.uint64);
+	return obj->value.uint64;
 }
 
 void
@@ -1023,13 +1023,13 @@ numlen(uint32_t num) {
 	size_t count = 0;
 
 	if (period == 0) {
-		return (1);
+		return 1;
 	}
 	while (period > 0) {
 		count++;
 		period /= 10;
 	}
-	return (count);
+	return count;
 }
 
 /*
@@ -1140,7 +1140,7 @@ cfg_print_duration_or_unlimited(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 bool
 cfg_obj_isduration(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_duration);
+	return obj->type->rep == &cfg_rep_duration;
 }
 
 uint32_t
@@ -1161,7 +1161,7 @@ parse_duration(cfg_parser_t *pctx, cfg_obj_t **ret) {
 	if (result == ISC_R_RANGE) {
 		cfg_parser_error(pctx, CFG_LOG_NEAR,
 				 "duration or TTL out of range");
-		return (result);
+		return result;
 	} else if (result != ISC_R_SUCCESS) {
 		goto cleanup;
 	}
@@ -1170,12 +1170,12 @@ parse_duration(cfg_parser_t *pctx, cfg_obj_t **ret) {
 	obj->value.duration = duration;
 	*ret = obj;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	cfg_parser_error(pctx, CFG_LOG_NEAR,
 			 "expected ISO 8601 duration or TTL value");
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -1191,12 +1191,12 @@ cfg_parse_duration(cfg_parser_t *pctx, const cfg_type_t *type,
 		goto cleanup;
 	}
 
-	return (parse_duration(pctx, ret));
+	return parse_duration(pctx, ret);
 
 cleanup:
 	cfg_parser_error(pctx, CFG_LOG_NEAR,
 			 "expected ISO 8601 duration or TTL value");
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -1224,15 +1224,15 @@ cfg_parse_duration_or_unlimited(cfg_parser_t *pctx, const cfg_type_t *type,
 		CHECK(cfg_create_obj(pctx, &cfg_type_duration, &obj));
 		obj->value.duration = duration;
 		*ret = obj;
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
-	return (parse_duration(pctx, ret));
+	return parse_duration(pctx, ret);
 
 cleanup:
 	cfg_parser_error(pctx, CFG_LOG_NEAR,
 			 "expected ISO 8601 duration, TTL value, or unlimited");
-	return (result);
+	return result;
 }
 
 /*%
@@ -1279,14 +1279,14 @@ create_string(cfg_parser_t *pctx, const char *contents, const cfg_type_t *type,
 	obj->value.string.base = isc_mem_get(pctx->mctx, len + 1);
 	if (obj->value.string.base == 0) {
 		isc_mem_put(pctx->mctx, obj, sizeof(*obj));
-		return (ISC_R_NOMEMORY);
+		return ISC_R_NOMEMORY;
 	}
 	memmove(obj->value.string.base, contents, len);
 	obj->value.string.base[len] = '\0';
 
 	*ret = obj;
 cleanup:
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -1301,12 +1301,11 @@ cfg_parse_qstring(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	CHECK(cfg_gettoken(pctx, CFG_LEXOPT_QSTRING));
 	if (pctx->token.type != isc_tokentype_qstring) {
 		cfg_parser_error(pctx, CFG_LOG_NEAR, "expected quoted string");
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
-	return (create_string(pctx, TOKEN_STRING(pctx), &cfg_type_qstring,
-			      ret));
+	return create_string(pctx, TOKEN_STRING(pctx), &cfg_type_qstring, ret);
 cleanup:
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -1319,12 +1318,11 @@ parse_ustring(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	if (pctx->token.type != isc_tokentype_string) {
 		cfg_parser_error(pctx, CFG_LOG_NEAR,
 				 "expected unquoted string");
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
-	return (create_string(pctx, TOKEN_STRING(pctx), &cfg_type_ustring,
-			      ret));
+	return create_string(pctx, TOKEN_STRING(pctx), &cfg_type_ustring, ret);
 cleanup:
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -1337,10 +1335,9 @@ cfg_parse_astring(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	UNUSED(type);
 
 	CHECK(cfg_getstringtoken(pctx));
-	return (create_string(pctx, TOKEN_STRING(pctx), &cfg_type_qstring,
-			      ret));
+	return create_string(pctx, TOKEN_STRING(pctx), &cfg_type_qstring, ret);
 cleanup:
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -1353,10 +1350,9 @@ cfg_parse_sstring(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	UNUSED(type);
 
 	CHECK(cfg_getstringtoken(pctx));
-	return (create_string(pctx, TOKEN_STRING(pctx), &cfg_type_sstring,
-			      ret));
+	return create_string(pctx, TOKEN_STRING(pctx), &cfg_type_sstring, ret);
 cleanup:
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -1368,12 +1364,12 @@ parse_btext(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	CHECK(cfg_gettoken(pctx, ISC_LEXOPT_BTEXT));
 	if (pctx->token.type != isc_tokentype_btext) {
 		cfg_parser_error(pctx, CFG_LOG_NEAR, "expected bracketed text");
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
-	return (create_string(pctx, TOKEN_STRING(pctx),
-			      &cfg_type_bracketed_text, ret));
+	return create_string(pctx, TOKEN_STRING(pctx), &cfg_type_bracketed_text,
+			     ret);
 cleanup:
-	return (result);
+	return result;
 }
 
 static void
@@ -1407,10 +1403,10 @@ cfg_is_enum(const char *s, const char *const *enums) {
 
 	for (p = enums; *p != NULL; p++) {
 		if (strcasecmp(*p, s) == 0) {
-			return (true);
+			return true;
 		}
 	}
-	return (false);
+	return false;
 }
 
 static isc_result_t
@@ -1418,10 +1414,10 @@ check_enum(cfg_parser_t *pctx, cfg_obj_t *obj, const char *const *enums) {
 	const char *s = obj->value.string.base;
 
 	if (cfg_is_enum(s, enums)) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 	cfg_parser_error(pctx, 0, "'%s' unexpected", s);
-	return (ISC_R_UNEXPECTEDTOKEN);
+	return ISC_R_UNEXPECTEDTOKEN;
 }
 
 isc_result_t
@@ -1436,10 +1432,10 @@ cfg_parse_enum(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	CHECK(parse_ustring(pctx, NULL, &obj));
 	CHECK(check_enum(pctx, obj, type->of));
 	*ret = obj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 cleanup:
 	CLEANUP_OBJ(obj);
-	return (result);
+	return result;
 }
 
 void
@@ -1472,7 +1468,7 @@ cfg_parse_enum_or_other(cfg_parser_t *pctx, const cfg_type_t *enumtype,
 		CHECK(cfg_parse_obj(pctx, othertype, ret));
 	}
 cleanup:
-	return (result);
+	return result;
 }
 
 void
@@ -1578,13 +1574,13 @@ free_sockaddrtls(cfg_parser_t *pctx, cfg_obj_t *obj) {
 bool
 cfg_obj_isstring(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_string);
+	return obj->type->rep == &cfg_rep_string;
 }
 
 const char *
 cfg_obj_asstring(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL && obj->type->rep == &cfg_rep_string);
-	return (obj->value.string.base);
+	return obj->value.string.base;
 }
 
 /* Quoted string only */
@@ -1674,11 +1670,11 @@ parse_geoip(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	CHECK(cfg_parse_obj(pctx, fields[3].type, &obj->value.tuple[3]));
 
 	*ret = obj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	CLEANUP_OBJ(obj);
-	return (result);
+	return result;
 }
 
 static void
@@ -1732,7 +1728,7 @@ parse_addrmatchelt(cfg_parser_t *pctx, const cfg_type_t *type,
 			cfg_parser_error(pctx, CFG_LOG_NEAR,
 					 "'geoip' "
 					 "not supported in this build");
-			return (ISC_R_UNEXPECTEDTOKEN);
+			return ISC_R_UNEXPECTEDTOKEN;
 #endif /* if defined(HAVE_GEOIP2) */
 		} else {
 			if (cfg_lookingat_netaddr(
@@ -1759,10 +1755,10 @@ parse_addrmatchelt(cfg_parser_t *pctx, const cfg_type_t *type,
 	bad:
 		cfg_parser_error(pctx, CFG_LOG_NEAR,
 				 "expected IP match list element");
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
 cleanup:
-	return (result);
+	return result;
 }
 
 /*%
@@ -1820,7 +1816,7 @@ parse_optional_btext(cfg_parser_t *pctx, const cfg_type_t *type,
 		CHECK(cfg_parse_obj(pctx, &cfg_type_void, ret));
 	}
 cleanup:
-	return (result);
+	return result;
 }
 
 static void
@@ -1856,13 +1852,13 @@ cfg_type_t cfg_type_optional_bracketed_text = { "optional_btext",
 bool
 cfg_obj_isboolean(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_boolean);
+	return obj->type->rep == &cfg_rep_boolean;
 }
 
 bool
 cfg_obj_asboolean(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL && obj->type->rep == &cfg_rep_boolean);
-	return (obj->value.boolean);
+	return obj->value.boolean;
 }
 
 isc_result_t
@@ -1878,7 +1874,7 @@ cfg_parse_boolean(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 
 	result = cfg_gettoken(pctx, 0);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 
 	if (pctx->token.type != isc_tokentype_string) {
@@ -1902,14 +1898,14 @@ cfg_parse_boolean(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	CHECK(cfg_create_obj(pctx, &cfg_type_boolean, &obj));
 	obj->value.boolean = value;
 	*ret = obj;
-	return (result);
+	return result;
 
 bad_boolean:
 	cfg_parser_error(pctx, CFG_LOG_NEAR, "boolean expected");
-	return (ISC_R_UNEXPECTEDTOKEN);
+	return ISC_R_UNEXPECTEDTOKEN;
 
 cleanup:
-	return (result);
+	return result;
 }
 
 void
@@ -1943,7 +1939,7 @@ cfg_create_list(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **obj) {
 	CHECK(cfg_create_obj(pctx, type, obj));
 	ISC_LIST_INIT((*obj)->value.list);
 cleanup:
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -1954,7 +1950,7 @@ create_listelt(cfg_parser_t *pctx, cfg_listelt_t **eltp) {
 	elt->obj = NULL;
 	ISC_LINK_INIT(elt, link);
 	*eltp = elt;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static void
@@ -1995,11 +1991,11 @@ cfg_parse_listelt(cfg_parser_t *pctx, const cfg_type_t *elttype,
 	elt->obj = value;
 
 	*ret = elt;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	isc_mem_put(pctx->mctx, elt, sizeof(*elt));
-	return (result);
+	return result;
 }
 
 /*
@@ -2028,14 +2024,14 @@ parse_list(cfg_parser_t *pctx, const cfg_type_t *listtype, cfg_obj_t **ret) {
 		elt = NULL;
 	}
 	*ret = listobj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	if (elt != NULL) {
 		free_listelt(pctx, elt);
 	}
 	CLEANUP_OBJ(listobj);
-	return (result);
+	return result;
 }
 
 static void
@@ -2070,7 +2066,7 @@ cfg_parse_bracketed_list(cfg_parser_t *pctx, const cfg_type_t *type,
 	CHECK(parse_list(pctx, type, ret));
 	CHECK(cfg_parse_special(pctx, '}'));
 cleanup:
-	return (result);
+	return result;
 }
 
 void
@@ -2126,11 +2122,11 @@ cfg_parse_spacelist(cfg_parser_t *pctx, const cfg_type_t *listtype,
 		ISC_LIST_APPEND(listobj->value.list, elt, link);
 	}
 	*ret = listobj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	CLEANUP_OBJ(listobj);
-	return (result);
+	return result;
 }
 
 void
@@ -2156,22 +2152,22 @@ cfg_print_spacelist(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 bool
 cfg_obj_islist(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_list);
+	return obj->type->rep == &cfg_rep_list;
 }
 
 const cfg_listelt_t *
 cfg_list_first(const cfg_obj_t *obj) {
 	REQUIRE(obj == NULL || obj->type->rep == &cfg_rep_list);
 	if (obj == NULL) {
-		return (NULL);
+		return NULL;
 	}
-	return (ISC_LIST_HEAD(obj->value.list));
+	return ISC_LIST_HEAD(obj->value.list);
 }
 
 const cfg_listelt_t *
 cfg_list_next(const cfg_listelt_t *elt) {
 	REQUIRE(elt != NULL);
-	return (ISC_LIST_NEXT(elt, link));
+	return ISC_LIST_NEXT(elt, link);
 }
 
 /*
@@ -2184,7 +2180,7 @@ cfg_list_length(const cfg_obj_t *obj, bool recurse) {
 	unsigned int count = 0;
 
 	if (obj == NULL || !cfg_obj_islist(obj)) {
-		return (0U);
+		return 0U;
 	}
 	for (elt = cfg_list_first(obj); elt != NULL; elt = cfg_list_next(elt)) {
 		if (recurse && cfg_obj_islist(elt->obj)) {
@@ -2193,13 +2189,13 @@ cfg_list_length(const cfg_obj_t *obj, bool recurse) {
 			count++;
 		}
 	}
-	return (count);
+	return count;
 }
 
 cfg_obj_t *
 cfg_listelt_value(const cfg_listelt_t *elt) {
 	REQUIRE(elt != NULL);
-	return (elt->obj);
+	return elt->obj;
 }
 
 /*
@@ -2435,14 +2431,14 @@ cfg_parse_mapbody(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	}
 
 	*ret = obj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	CLEANUP_OBJ(value);
 	CLEANUP_OBJ(obj);
 	CLEANUP_OBJ(eltobj);
 	CLEANUP_OBJ(includename);
-	return (result);
+	return result;
 }
 
 static isc_result_t
@@ -2460,11 +2456,11 @@ parse_symtab_elt(cfg_parser_t *pctx, const char *name, cfg_type_t *elttype,
 
 	symval.as_pointer = obj;
 	CHECK(isc_symtab_define(symtab, name, 1, symval, isc_symexists_reject));
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	CLEANUP_OBJ(obj);
-	return (result);
+	return result;
 }
 
 /*
@@ -2482,7 +2478,7 @@ cfg_parse_map(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	CHECK(cfg_parse_mapbody(pctx, type, ret));
 	CHECK(cfg_parse_special(pctx, '}'));
 cleanup:
-	return (result);
+	return result;
 }
 
 /*
@@ -2504,11 +2500,11 @@ parse_any_named_map(cfg_parser_t *pctx, cfg_type_t *nametype,
 	CHECK(cfg_parse_map(pctx, type, &mapobj));
 	mapobj->value.map.id = idobj;
 	*ret = mapobj;
-	return (result);
+	return result;
 cleanup:
 	CLEANUP_OBJ(idobj);
 	CLEANUP_OBJ(mapobj);
-	return (result);
+	return result;
 }
 
 /*
@@ -2518,7 +2514,7 @@ cleanup:
 isc_result_t
 cfg_parse_named_map(cfg_parser_t *pctx, const cfg_type_t *type,
 		    cfg_obj_t **ret) {
-	return (parse_any_named_map(pctx, &cfg_type_astring, type, ret));
+	return parse_any_named_map(pctx, &cfg_type_astring, type, ret);
 }
 
 /*
@@ -2528,7 +2524,7 @@ cfg_parse_named_map(cfg_parser_t *pctx, const cfg_type_t *type,
 isc_result_t
 cfg_parse_addressed_map(cfg_parser_t *pctx, const cfg_type_t *type,
 			cfg_obj_t **ret) {
-	return (parse_any_named_map(pctx, &cfg_type_netaddr, type, ret));
+	return parse_any_named_map(pctx, &cfg_type_netaddr, type, ret);
 }
 
 /*
@@ -2538,7 +2534,7 @@ cfg_parse_addressed_map(cfg_parser_t *pctx, const cfg_type_t *type,
 isc_result_t
 cfg_parse_netprefix_map(cfg_parser_t *pctx, const cfg_type_t *type,
 			cfg_obj_t **ret) {
-	return (parse_any_named_map(pctx, &cfg_type_netprefix, type, ret));
+	return parse_any_named_map(pctx, &cfg_type_netprefix, type, ret);
 }
 
 static void
@@ -2727,7 +2723,7 @@ cfg_doc_map(cfg_printer_t *pctx, const cfg_type_t *type) {
 bool
 cfg_obj_ismap(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_map);
+	return obj->type->rep == &cfg_rep_map;
 }
 
 isc_result_t
@@ -2744,16 +2740,16 @@ cfg_map_get(const cfg_obj_t *mapobj, const char *name, const cfg_obj_t **obj) {
 
 	result = isc_symtab_lookup(map->symtab, name, MAP_SYM, &val);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 	*obj = val.as_pointer;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 const cfg_obj_t *
 cfg_map_getname(const cfg_obj_t *mapobj) {
 	REQUIRE(mapobj != NULL && mapobj->type->rep == &cfg_rep_map);
-	return (mapobj->value.map.id);
+	return mapobj->value.map.id;
 }
 
 unsigned int
@@ -2763,7 +2759,7 @@ cfg_map_count(const cfg_obj_t *mapobj) {
 	REQUIRE(mapobj != NULL && mapobj->type->rep == &cfg_rep_map);
 
 	map = &mapobj->value.map;
-	return (isc_symtab_count(map->symtab));
+	return isc_symtab_count(map->symtab);
 }
 
 const char *
@@ -2777,17 +2773,17 @@ cfg_map_firstclause(const cfg_type_t *map, const void **clauses,
 
 	clauseset = map->of;
 	if (*clauseset == NULL) {
-		return (NULL);
+		return NULL;
 	}
 	*clauses = *clauseset;
 	*idx = 0;
 	while ((*clauseset)[*idx].name == NULL) {
 		*clauses = (*++clauseset);
 		if (*clauses == NULL) {
-			return (NULL);
+			return NULL;
 		}
 	}
-	return ((*clauseset)[*idx].name);
+	return (*clauseset)[*idx].name;
 }
 
 const char *
@@ -2809,10 +2805,10 @@ cfg_map_nextclause(const cfg_type_t *map, const void **clauses,
 		*idx = 0;
 		*clauses = (*++clauseset);
 		if (*clauses == NULL) {
-			return (NULL);
+			return NULL;
 		}
 	}
-	return ((*clauseset)[*idx].name);
+	return (*clauseset)[*idx].name;
 }
 
 /* Parse an arbitrary token, storing its raw text representation. */
@@ -2839,13 +2835,13 @@ parse_token(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	memmove(obj->value.string.base, r.base, r.length);
 	obj->value.string.base[r.length] = '\0';
 	*ret = obj;
-	return (result);
+	return result;
 
 cleanup:
 	if (obj != NULL) {
 		isc_mem_put(pctx->mctx, obj, sizeof(*obj));
 	}
-	return (result);
+	return result;
 }
 
 cfg_type_t cfg_type_token = { "token",		 parse_token,
@@ -2892,11 +2888,11 @@ parse_unsupported(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	}
 	INSIST(braces == 0);
 	*ret = listobj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	CLEANUP_OBJ(listobj);
-	return (result);
+	return result;
 }
 
 cfg_type_t cfg_type_unsupported = { "unsupported",	 parse_unsupported,
@@ -2919,17 +2915,17 @@ token_addr(cfg_parser_t *pctx, unsigned int flags, isc_netaddr_t *na) {
 	struct in6_addr in6a;
 
 	if (pctx->token.type != isc_tokentype_string) {
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
 
 	s = TOKEN_STRING(pctx);
 	if ((flags & CFG_ADDR_WILDOK) != 0 && strcmp(s, "*") == 0) {
 		if ((flags & CFG_ADDR_V4OK) != 0) {
 			isc_netaddr_any(na);
-			return (ISC_R_SUCCESS);
+			return ISC_R_SUCCESS;
 		} else if ((flags & CFG_ADDR_V6OK) != 0) {
 			isc_netaddr_any6(na);
-			return (ISC_R_SUCCESS);
+			return ISC_R_SUCCESS;
 		} else {
 			UNREACHABLE();
 		}
@@ -2937,7 +2933,7 @@ token_addr(cfg_parser_t *pctx, unsigned int flags, isc_netaddr_t *na) {
 		if ((flags & (CFG_ADDR_V4OK | CFG_ADDR_V4PREFIXOK)) != 0) {
 			if (inet_pton(AF_INET, s, &in4a) == 1) {
 				isc_netaddr_fromin(na, &in4a);
-				return (ISC_R_SUCCESS);
+				return ISC_R_SUCCESS;
 			}
 		}
 		if ((flags & CFG_ADDR_V4PREFIXOK) != 0 && strlen(s) <= 15U) {
@@ -2949,7 +2945,7 @@ token_addr(cfg_parser_t *pctx, unsigned int flags, isc_netaddr_t *na) {
 				strlcat(buf, ".0", sizeof(buf));
 				if (inet_pton(AF_INET, buf, &in4a) == 1) {
 					isc_netaddr_fromin(na, &in4a);
-					return (ISC_R_IPV4PREFIX);
+					return ISC_R_IPV4PREFIX;
 				}
 			}
 		}
@@ -2971,17 +2967,17 @@ token_addr(cfg_parser_t *pctx, unsigned int flags, isc_netaddr_t *na) {
 					result = isc_netscope_pton(
 						AF_INET6, d + 1, &in6a, &zone);
 					if (result != ISC_R_SUCCESS) {
-						return (result);
+						return result;
 					}
 				}
 
 				isc_netaddr_fromin6(na, &in6a);
 				isc_netaddr_setzone(na, zone);
-				return (ISC_R_SUCCESS);
+				return ISC_R_SUCCESS;
 			}
 		}
 	}
-	return (ISC_R_UNEXPECTEDTOKEN);
+	return ISC_R_UNEXPECTEDTOKEN;
 }
 
 isc_result_t
@@ -3017,7 +3013,7 @@ cfg_parse_rawaddr(cfg_parser_t *pctx, unsigned int flags, isc_netaddr_t *na) {
 		}
 	}
 cleanup:
-	return (result);
+	return result;
 }
 
 bool
@@ -3028,7 +3024,7 @@ cfg_lookingat_netaddr(cfg_parser_t *pctx, unsigned int flags) {
 	REQUIRE(pctx != NULL);
 
 	result = token_addr(pctx, flags, &na_dummy);
-	return (result == ISC_R_SUCCESS || result == ISC_R_IPV4PREFIX);
+	return result == ISC_R_SUCCESS || result == ISC_R_IPV4PREFIX;
 }
 
 isc_result_t
@@ -3045,22 +3041,22 @@ cfg_parse_rawport(cfg_parser_t *pctx, unsigned int flags, in_port_t *port) {
 	    strcmp(TOKEN_STRING(pctx), "*") == 0)
 	{
 		*port = 0;
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 	if (pctx->token.type != isc_tokentype_number) {
 		cfg_parser_error(pctx, CFG_LOG_NEAR,
 				 "expected port number or '*'");
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
 	if (pctx->token.value.as_ulong >= 65536U) {
 		cfg_parser_error(pctx, CFG_LOG_NEAR,
 				 "port number out of range");
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
 	*port = (in_port_t)(pctx->token.value.as_ulong);
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 cleanup:
-	return (result);
+	return result;
 }
 
 void
@@ -3098,10 +3094,10 @@ parse_netaddr(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	CHECK(cfg_parse_rawaddr(pctx, flags, &netaddr));
 	isc_sockaddr_fromnetaddr(&obj->value.sockaddr, &netaddr, 0);
 	*ret = obj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 cleanup:
 	CLEANUP_OBJ(obj);
-	return (result);
+	return result;
 }
 
 static void
@@ -3197,13 +3193,13 @@ cfg_parse_netprefix(cfg_parser_t *pctx, const cfg_type_t *type,
 		if (pctx->token.type != isc_tokentype_number) {
 			cfg_parser_error(pctx, CFG_LOG_NEAR,
 					 "expected prefix length");
-			return (ISC_R_UNEXPECTEDTOKEN);
+			return ISC_R_UNEXPECTEDTOKEN;
 		}
 		prefixlen = pctx->token.value.as_ulong;
 		if (prefixlen > addrlen) {
 			cfg_parser_error(pctx, CFG_LOG_NOPREP,
 					 "invalid prefix length");
-			return (ISC_R_RANGE);
+			return ISC_R_RANGE;
 		}
 		result = isc_netaddr_prefixok(&netaddr, prefixlen);
 		if (result != ISC_R_SUCCESS) {
@@ -3213,13 +3209,13 @@ cfg_parse_netprefix(cfg_parser_t *pctx, const cfg_type_t *type,
 					 "'%s/%u': address/prefix length "
 					 "mismatch",
 					 buf, prefixlen);
-			return (ISC_R_FAILURE);
+			return ISC_R_FAILURE;
 		}
 	} else {
 		if (expectprefix) {
 			cfg_parser_error(pctx, CFG_LOG_NEAR,
 					 "incomplete IPv4 address or prefix");
-			return (ISC_R_FAILURE);
+			return ISC_R_FAILURE;
 		}
 		prefixlen = addrlen;
 	}
@@ -3227,10 +3223,10 @@ cfg_parse_netprefix(cfg_parser_t *pctx, const cfg_type_t *type,
 	obj->value.netprefix.address = netaddr;
 	obj->value.netprefix.prefixlen = prefixlen;
 	*ret = obj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 cleanup:
 	cfg_parser_error(pctx, CFG_LOG_NEAR, "expected network prefix");
-	return (result);
+	return result;
 }
 
 static void
@@ -3245,7 +3241,7 @@ print_netprefix(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 bool
 cfg_obj_isnetprefix(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_netprefix);
+	return obj->type->rep == &cfg_rep_netprefix;
 }
 
 void
@@ -3323,11 +3319,11 @@ parse_sockaddrsub(cfg_parser_t *pctx, const cfg_type_t *type, int flags,
 
 	isc_sockaddr_fromnetaddr(&obj->value.sockaddr, &netaddr, port);
 	*ret = obj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	CLEANUP_OBJ(obj);
-	return (result);
+	return result;
 }
 
 static unsigned int sockaddr_flags = CFG_ADDR_V4OK | CFG_ADDR_V6OK |
@@ -3353,7 +3349,7 @@ cfg_parse_sockaddr(cfg_parser_t *pctx, const cfg_type_t *type,
 
 	flagp = type->of;
 
-	return (parse_sockaddrsub(pctx, &cfg_type_sockaddr, *flagp, ret));
+	return parse_sockaddrsub(pctx, &cfg_type_sockaddr, *flagp, ret);
 }
 
 isc_result_t
@@ -3367,7 +3363,7 @@ cfg_parse_sockaddrtls(cfg_parser_t *pctx, const cfg_type_t *type,
 
 	flagp = type->of;
 
-	return (parse_sockaddrsub(pctx, &cfg_type_sockaddrtls, *flagp, ret));
+	return parse_sockaddrsub(pctx, &cfg_type_sockaddrtls, *flagp, ret);
 }
 
 void
@@ -3439,13 +3435,13 @@ cfg_doc_sockaddr(cfg_printer_t *pctx, const cfg_type_t *type) {
 bool
 cfg_obj_issockaddr(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_sockaddr);
+	return obj->type->rep == &cfg_rep_sockaddr;
 }
 
 bool
 cfg_obj_issockaddrtls(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_sockaddrtls);
+	return obj->type->rep == &cfg_rep_sockaddrtls;
 }
 
 const isc_sockaddr_t *
@@ -3453,13 +3449,13 @@ cfg_obj_assockaddr(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
 	REQUIRE(obj->type->rep == &cfg_rep_sockaddr ||
 		obj->type->rep == &cfg_rep_sockaddrtls);
-	return (&obj->value.sockaddr);
+	return &obj->value.sockaddr;
 }
 
 const char *
 cfg_obj_getsockaddrtls(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL && obj->type->rep == &cfg_rep_sockaddrtls);
-	return (obj->value.sockaddrtls.tls.base);
+	return obj->value.sockaddrtls.tls.base;
 }
 
 isc_result_t
@@ -3469,7 +3465,7 @@ cfg_gettoken(cfg_parser_t *pctx, int options) {
 	REQUIRE(pctx != NULL);
 
 	if (pctx->seen_eof) {
-		return (ISC_R_SUCCESS);
+		return ISC_R_SUCCESS;
 	}
 
 	options |= (ISC_LEXOPT_EOF | ISC_LEXOPT_NOMORE);
@@ -3519,7 +3515,7 @@ redo:
 				 isc_result_totext(result));
 		break;
 	}
-	return (result);
+	return result;
 }
 
 void
@@ -3542,7 +3538,7 @@ cfg_peektoken(cfg_parser_t *pctx, int options) {
 	CHECK(cfg_gettoken(pctx, options));
 	cfg_ungettoken(pctx);
 cleanup:
-	return (result);
+	return result;
 }
 
 /*
@@ -3555,16 +3551,16 @@ cfg_getstringtoken(cfg_parser_t *pctx) {
 
 	result = cfg_gettoken(pctx, CFG_LEXOPT_QSTRING);
 	if (result != ISC_R_SUCCESS) {
-		return (result);
+		return result;
 	}
 
 	if (pctx->token.type != isc_tokentype_string &&
 	    pctx->token.type != isc_tokentype_qstring)
 	{
 		cfg_parser_error(pctx, CFG_LOG_NEAR, "expected string");
-		return (ISC_R_UNEXPECTEDTOKEN);
+		return ISC_R_UNEXPECTEDTOKEN;
 	}
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 void
@@ -3600,15 +3596,15 @@ static bool
 have_current_file(cfg_parser_t *pctx) {
 	cfg_listelt_t *elt;
 	if (pctx->open_files == NULL) {
-		return (false);
+		return false;
 	}
 
 	elt = ISC_LIST_TAIL(pctx->open_files->value.list);
 	if (elt == NULL) {
-		return (false);
+		return false;
 	}
 
-	return (true);
+	return true;
 }
 
 static char *
@@ -3618,17 +3614,17 @@ current_file(cfg_parser_t *pctx) {
 	cfg_obj_t *fileobj;
 
 	if (!have_current_file(pctx)) {
-		return (none);
+		return none;
 	}
 
 	elt = ISC_LIST_TAIL(pctx->open_files->value.list);
 	if (elt == NULL) { /* shouldn't be possible, but... */
-		return (none);
+		return none;
 	}
 
 	fileobj = elt->obj;
 	INSIST(fileobj->type == &cfg_type_qstring);
-	return (fileobj->value.string.base);
+	return fileobj->value.string.base;
 }
 
 static void
@@ -3727,14 +3723,14 @@ const char *
 cfg_obj_file(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
 
-	return (obj->file);
+	return obj->file;
 }
 
 unsigned int
 cfg_obj_line(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
 
-	return (obj->line);
+	return obj->line;
 }
 
 isc_result_t
@@ -3754,7 +3750,7 @@ cfg_create_obj(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 
 	*ret = obj;
 
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 }
 
 static void
@@ -3782,13 +3778,13 @@ create_map(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	obj->value.map.id = NULL;
 
 	*ret = obj;
-	return (ISC_R_SUCCESS);
+	return ISC_R_SUCCESS;
 
 cleanup:
 	if (obj != NULL) {
 		isc_mem_put(pctx->mctx, obj, sizeof(*obj));
 	}
-	return (result);
+	return result;
 }
 
 static void
@@ -3802,7 +3798,7 @@ cfg_obj_istype(const cfg_obj_t *obj, const cfg_type_t *type) {
 	REQUIRE(obj != NULL);
 	REQUIRE(type != NULL);
 
-	return (obj->type == type);
+	return obj->type == type;
 }
 
 /*
@@ -3898,7 +3894,7 @@ cfg_parser_mapadd(cfg_parser_t *pctx, cfg_obj_t *mapobj, cfg_obj_t *obj,
 
 breakout:
 	if (clause == NULL || clause->name == NULL) {
-		return (ISC_R_FAILURE);
+		return ISC_R_FAILURE;
 	}
 
 	result = isc_symtab_lookup(map->symtab, clausename, 0, &symval);
@@ -3939,7 +3935,7 @@ cleanup:
 	}
 	CLEANUP_OBJ(destobj);
 
-	return (result);
+	return result;
 }
 
 isc_result_t
@@ -3968,7 +3964,7 @@ cfg_pluginlist_foreach(const cfg_obj_t *config, const cfg_obj_t *list,
 		if (strcasecmp(type, "query") != 0) {
 			cfg_obj_log(obj, lctx, ISC_LOG_ERROR,
 				    "unsupported plugin type");
-			return (ISC_R_FAILURE);
+			return ISC_R_FAILURE;
 		}
 
 		library = cfg_obj_asstring(cfg_tuple_get(plugin, "library"));
@@ -3985,5 +3981,5 @@ cfg_pluginlist_foreach(const cfg_obj_t *config, const cfg_obj_t *list,
 		}
 	}
 
-	return (result);
+	return result;
 }
